@@ -95,7 +95,7 @@ class _OpenTelemetryPlugin:
 
     def _should_record(self, stats_data: StatsData) -> bool:
         # Decide if this plugin should record the stats_data.
-        return stats_data.name in self._metric_to_recorder.keys()
+        return stats_data.name in self._metric_to_recorder
 
     def _record_stats_data(self, stats_data: StatsData) -> None:
         recorder = self._metric_to_recorder[stats_data.name]
@@ -250,26 +250,11 @@ class _OpenTelemetryPlugin:
                     unit=metric.unit,
                     description=metric.description,
                 )
-            elif metric == _open_telemetry_measures.CLIENT_ATTEMPT_DURATION:
-                recorder = meter.create_histogram(
-                    name=metric.name,
-                    unit=metric.unit,
-                    description=metric.description,
-                )
-            elif metric == _open_telemetry_measures.CLIENT_RPC_DURATION:
-                recorder = meter.create_histogram(
-                    name=metric.name,
-                    unit=metric.unit,
-                    description=metric.description,
-                )
-            elif metric == _open_telemetry_measures.CLIENT_ATTEMPT_SEND_BYTES:
-                recorder = meter.create_histogram(
-                    name=metric.name,
-                    unit=metric.unit,
-                    description=metric.description,
-                )
-            elif (
-                metric == _open_telemetry_measures.CLIENT_ATTEMPT_RECEIVED_BYTES
+            elif metric in (
+                _open_telemetry_measures.CLIENT_ATTEMPT_DURATION,
+                _open_telemetry_measures.CLIENT_RPC_DURATION,
+                _open_telemetry_measures.CLIENT_ATTEMPT_SEND_BYTES,
+                _open_telemetry_measures.CLIENT_ATTEMPT_RECEIVED_BYTES,
             ):
                 recorder = meter.create_histogram(
                     name=metric.name,
@@ -282,19 +267,11 @@ class _OpenTelemetryPlugin:
                     unit=metric.unit,
                     description=metric.description,
                 )
-            elif metric == _open_telemetry_measures.SERVER_RPC_DURATION:
-                recorder = meter.create_histogram(
-                    name=metric.name,
-                    unit=metric.unit,
-                    description=metric.description,
-                )
-            elif metric == _open_telemetry_measures.SERVER_RPC_SEND_BYTES:
-                recorder = meter.create_histogram(
-                    name=metric.name,
-                    unit=metric.unit,
-                    description=metric.description,
-                )
-            elif metric == _open_telemetry_measures.SERVER_RPC_RECEIVED_BYTES:
+            elif metric in (
+                _open_telemetry_measures.SERVER_RPC_DURATION,
+                _open_telemetry_measures.SERVER_RPC_SEND_BYTES,
+                _open_telemetry_measures.SERVER_RPC_RECEIVED_BYTES,
+            ):
                 recorder = meter.create_histogram(
                     name=metric.name,
                     unit=metric.unit,
@@ -490,10 +467,9 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
             self._server_option_activated = True
 
     def _get_identifier(self) -> str:
-        plugin_identifiers = []
-        for _plugin in self._plugins:
-            plugin_identifiers.append(_plugin.identifier)
-        return PLUGIN_IDENTIFIER_SEP.join(plugin_identifiers)
+        return PLUGIN_IDENTIFIER_SEP.join(
+            _plugin.identifier for _plugin in self._plugins
+        )
 
     def get_enabled_optional_labels(self) -> List[OptionalLabelType]:
         return []
@@ -502,7 +478,7 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
 def _start_open_telemetry_observability(
     otel_o11y: OpenTelemetryObservability,
 ) -> None:
-    global _OPEN_TELEMETRY_OBSERVABILITY  # pylint: disable=global-statement
+    global _OPEN_TELEMETRY_OBSERVABILITY  # pylint: disable=global-statement # noqa: PLW0603
     with _observability_lock:
         if _OPEN_TELEMETRY_OBSERVABILITY is None:
             _OPEN_TELEMETRY_OBSERVABILITY = otel_o11y
@@ -513,11 +489,10 @@ def _start_open_telemetry_observability(
 
 
 def _end_open_telemetry_observability() -> None:
-    global _OPEN_TELEMETRY_OBSERVABILITY  # pylint: disable=global-statement
+    global _OPEN_TELEMETRY_OBSERVABILITY  # pylint: disable=global-statement # noqa: PLW0603
     with _observability_lock:
         if not _OPEN_TELEMETRY_OBSERVABILITY:
             error_msg = "Trying to end gPRC Python observability without initialize first!"
             raise RuntimeError(error_msg)
-        else:
-            _OPEN_TELEMETRY_OBSERVABILITY.observability_deinit()
-            _OPEN_TELEMETRY_OBSERVABILITY = None
+        _OPEN_TELEMETRY_OBSERVABILITY.observability_deinit()
+        _OPEN_TELEMETRY_OBSERVABILITY = None
