@@ -21,18 +21,18 @@
 #include <atomic>
 #include <string>
 
+#include "metadata_exchange.h"
+#include "python_observability_context.h"
+#include "src/core/telemetry/call_tracer.h"
 #include "absl/base/thread_annotations.h"
 #include "absl/status/status.h"
 #include "absl/strings/escaping.h"
 #include "absl/strings/string_view.h"
 #include "absl/time/time.h"
-#include "metadata_exchange.h"
-#include "python_observability_context.h"
-#include "src/core/telemetry/call_tracer.h"
 
 namespace grpc_observability {
 
-class PythonOpenCensusCallTracer : public grpc_core::ClientCallTracer {
+class PythonOpenCensusCallTracer : public grpc_core::ClientCallTracerInterface {
  public:
   class PythonOpenCensusCallAttemptTracer : public CallAttemptTracer {
    public:
