@@ -24,14 +24,14 @@
 #include <string>
 #include <thread>
 
-#include "absl/log/check.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
 #include "src/core/lib/slice/slice_internal.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/match.h"
 #include "test/core/test_util/test_config.h"
 #include "test/core/test_util/tls_utils.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
 
 namespace grpc_core {
 
@@ -64,7 +64,7 @@ constexpr absl::string_view kSpiffeBundleMapPath2 =
 
 SpiffeBundleMap GetRawSpiffeBundleMap() {
   auto map = SpiffeBundleMap::FromFile(kSpiffeBundleMapPath);
-  CHECK(map.ok()) << map.status();
+  GRPC_CHECK(map.ok()) << map.status();
   return *map;
 }
 
@@ -74,7 +74,7 @@ std::shared_ptr<RootCertInfo> GetTestSpiffeBundleMap() {
 
 SpiffeBundleMap GetRawSpiffeBundleMap2() {
   auto map = SpiffeBundleMap::FromFile(kSpiffeBundleMapPath2);
-  CHECK(map.ok()) << map.status();
+  GRPC_CHECK(map.ok()) << map.status();
   return *map;
 }
 
@@ -194,7 +194,7 @@ class GrpcTlsCertificateDistributorTest : public ::testing::Test {
 
     void OnError(grpc_error_handle root_cert_error,
                  grpc_error_handle identity_cert_error) override {
-      CHECK(!root_cert_error.ok() || !identity_cert_error.ok());
+      GRPC_CHECK(!root_cert_error.ok() || !identity_cert_error.ok());
       std::string root_error_str;
       if (!root_cert_error.ok()) {
         root_error_str = std::string(root_cert_error.message());
