@@ -20,13 +20,13 @@
 #include <atomic>
 #include <memory>
 
-#include "absl/status/status.h"
-#include "gtest/gtest.h"
 #include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/util/time.h"
 #include "test/core/end2end/end2end_tests.h"
 #include "test/core/test_util/test_lb_policies.h"
+#include "gtest/gtest.h"
+#include "absl/status/status.h"
 
 namespace grpc_core {
 namespace {
@@ -46,7 +46,7 @@ CORE_END2END_TEST(RetryTests, RetryLbFail) {
             builder, absl::UnavailableError("LB pick failed"), &g_num_lb_picks);
       });
   g_num_lb_picks.store(0, std::memory_order_relaxed);
-  InitServer(ChannelArgs());
+  InitServer(DefaultServerArgs());
   InitClient(
       ChannelArgs()
           .Set(GRPC_ARG_ENABLE_RETRIES, true)
