@@ -23,20 +23,20 @@
 #include <string>
 #include <utility>
 
-#include "absl/log/check.h"
-#include "absl/log/log.h"
-#include "absl/strings/str_cat.h"
-#include "absl/time/time.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
+#include "src/core/credentials/call/call_credentials.h"
+#include "src/core/credentials/transport/fake/fake_credentials.h"
+#include "src/core/credentials/transport/security_connector.h"
 #include "src/core/ext/transport/chaotic_good/chaotic_good.h"
 #include "src/core/ext/transport/chaotic_good/client/chaotic_good_connector.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
+#include "src/core/lib/experiments/config.h"
+#include "src/core/lib/experiments/experiments.h"
 #include "src/core/server/server.h"
 #include "src/core/transport/endpoint_transport.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/notification.h"
 #include "src/core/util/time.h"
 #include "src/core/util/uri.h"
@@ -44,11 +44,22 @@
 #include "test/core/test_util/build.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "absl/log/log.h"
+#include "absl/strings/str_cat.h"
+#include "absl/time/time.h"
 
 namespace grpc_core {
 namespace chaotic_good {
 namespace testing {
-class ChaoticGoodServerTest : public ::testing::Test {
+
+enum class CredentialsType {
+  kInsecure,
+  kFake,
+};
+
+class ChaoticGoodServerTest : public ::testing::TestWithParam<CredentialsType> {
  public:
   ChaoticGoodServerTest() {
     StartServer();
@@ -73,8 +84,8 @@ class ChaoticGoodServerTest : public ::testing::Test {
     if (ev.type == GRPC_QUEUE_TIMEOUT) {
       AsanAssertNoLeaks();
     }
-    CHECK_EQ(ev.type, GRPC_OP_COMPLETE);
-    CHECK_EQ(ev.tag, nullptr);
+    GRPC_CHECK_EQ(ev.type, GRPC_OP_COMPLETE);
+    GRPC_CHECK_EQ(ev.tag, nullptr);
     grpc_completion_queue_destroy(shutdown_cq);
     grpc_server_destroy(server_);
   }
@@ -89,7 +100,15 @@ class ChaoticGoodServerTest : public ::testing::Test {
                                .ToC()
                                .get(),
                            nullptr);
-    auto* creds = grpc_insecure_server_credentials_create();
+    grpc_server_credentials* creds;
+    switch (GetParam()) {
+      case CredentialsType::kInsecure:
+        creds = grpc_insecure_server_credentials_create();
+        break;
+      case CredentialsType::kFake:
+        creds = grpc_fake_transport_security_server_credentials_create();
+        break;
+    }
     grpc_server_add_http2_port(server_, addr_.c_str(), creds);
     grpc_server_credentials_release(creds);
     grpc_server_start(server_);
@@ -97,11 +116,26 @@ class ChaoticGoodServerTest : public ::testing::Test {
 
   void ConstructConnector() {
     auto uri = URI::Parse("ipv6:" + addr_);
-    CHECK_OK(uri);
-    CHECK(grpc_parse_uri(*uri, &resolved_addr_));
+    GRPC_CHECK_OK(uri);
+    GRPC_CHECK(grpc_parse_uri(*uri, &resolved_addr_));
     args_.address = &resolved_addr_;
-    args_.deadline = Timestamp::Now() + Duration::Seconds(5);
+    args_.deadline = Timestamp::Now() + Duration::Seconds(15);
     args_.channel_args = channel_args();
+    grpc_channel_credentials* channel_creds = nullptr;
+    switch (GetParam()) {
+      case CredentialsType::kInsecure:
+        channel_creds = grpc_insecure_credentials_create();
+        break;
+      case CredentialsType::kFake:
+        channel_creds = grpc_fake_transport_security_credentials_create();
+        break;
+    }
+    LOG(ERROR) << "addr: " << uri->ToString();
+    args_.channel_args =
+        args_.channel_args.SetObject<grpc_channel_security_connector>(
+            channel_creds->create_security_connector(
+                nullptr, uri->ToString().c_str(), &args_.channel_args));
+    grpc_channel_credentials_release(channel_creds);
     connector_ = MakeRefCounted<ChaoticGoodConnector>();
   }
 
@@ -120,7 +154,6 @@ class ChaoticGoodServerTest : public ::testing::Test {
   }
 
   grpc_server* server_;
-  Server* core_server_;
   ChaoticGoodConnector::Args args_;
   ChaoticGoodConnector::Result connecting_result_;
   bool connecting_successful_ = false;
@@ -132,7 +165,7 @@ class ChaoticGoodServerTest : public ::testing::Test {
   RefCountedPtr<ChaoticGoodConnector> connector_;
 };
 
-TEST_F(ChaoticGoodServerTest, Connect) {
+TEST_P(ChaoticGoodServerTest, Connect) {
   if (!IsChaoticGoodFramingLayerEnabled()) {
     GTEST_SKIP() << "Chaotic Good framing layer is not enabled";
   }
@@ -140,9 +173,11 @@ TEST_F(ChaoticGoodServerTest, Connect) {
                     grpc_schedule_on_exec_ctx);
   connector_->Connect(args_, &connecting_result_, &on_connecting_finished_);
   connect_finished_.WaitForNotification();
+  absl::SleepFor(absl::Seconds(1));
+  EXPECT_TRUE(connecting_successful_);
 }
 
-TEST_F(ChaoticGoodServerTest, ConnectAndShutdown) {
+TEST_P(ChaoticGoodServerTest, ConnectAndShutdown) {
   if (!IsChaoticGoodFramingLayerEnabled()) {
     GTEST_SKIP() << "Chaotic Good framing layer is not enabled";
   }
@@ -157,12 +192,31 @@ TEST_F(ChaoticGoodServerTest, ConnectAndShutdown) {
   connect_finished_.WaitForNotification();
 }
 
+INSTANTIATE_TEST_SUITE_P(ChaoticGoodServerTest, ChaoticGoodServerTest,
+                         ::testing::Values(CredentialsType::kInsecure,
+                                           CredentialsType::kFake));
+
 }  // namespace testing
 }  // namespace chaotic_good
 }  // namespace grpc_core
 
 int main(int argc, char** argv) {
   ::testing::InitGoogleTest(&argc, argv);
+
+  // Register a comparator for the Fake credentials.
+  grpc_core::CoreConfiguration::RegisterEphemeralBuilder(
+      [&](grpc_core::CoreConfiguration::Builder* builder) {
+        builder->auth_context_comparator_registry()->RegisterComparator(
+            std::string("Fake"),
+            std::make_unique<absl::AnyInvocable<bool(
+                const grpc_auth_context*, const grpc_auth_context*)>>(
+                [&](const grpc_auth_context* one,
+                    const grpc_auth_context* two) -> bool {
+                  LOG(ERROR) << "compare";
+                  return true;
+                }));
+      });
+
   // Must call to create default EventEngine.
   grpc_init();
   int ret = RUN_ALL_TESTS();
