@@ -27,12 +27,6 @@
 #include <string>
 #include <vector>
 
-#include "absl/functional/any_invocable.h"
-#include "absl/status/status.h"
-#include "absl/status/statusor.h"
-#include "absl/strings/str_format.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
 #include "src/core/call/metadata_batch.h"
 #include "src/core/ext/transport/chaotic_good/chaotic_good_frame.pb.h"
 #include "src/core/lib/iomgr/timer_manager.h"
@@ -47,6 +41,12 @@
 #include "test/core/event_engine/fuzzing_event_engine/fuzzing_event_engine.pb.h"
 #include "test/core/transport/chaotic_good/mock_frame_transport.h"
 #include "test/core/transport/util/transport_test.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "absl/functional/any_invocable.h"
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
+#include "absl/strings/str_format.h"
 
 using testing::_;
 using testing::MockFunction;
@@ -105,12 +105,14 @@ class MockCallDestination : public UnstartedCallDestination {
 
 class MockServerConnectionFactory : public ServerConnectionFactory {
  public:
-  MOCK_METHOD(PendingConnection, RequestDataConnection, (), (override));
+  MOCK_METHOD(PendingConnection, RequestDataConnection, (const ChannelArgs&),
+              (override));
   void Orphaned() final {}
 };
 
 TEST_F(TransportTest, ReadAndWriteOneMessage) {
-  auto owned_frame_transport = MakeOrphanable<MockFrameTransport>();
+  auto owned_frame_transport =
+      MakeOrphanable<MockFrameTransport>(event_engine());
   auto* frame_transport = owned_frame_transport.get();
   auto call_destination = MakeRefCounted<StrictMock<MockCallDestination>>();
   EXPECT_CALL(*call_destination, Orphaned()).Times(1);
