@@ -19,12 +19,13 @@
 #include <initializer_list>
 #include <utility>
 
-#include "absl/status/status.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
+#include "src/core/call/message.h"
 #include "src/core/ext/transport/chttp2/transport/http2_settings.h"
 #include "src/core/ext/transport/chttp2/transport/http2_status.h"
 #include "src/core/lib/slice/slice_buffer.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "absl/status/status.h"
 
 namespace grpc_core {
 namespace {
@@ -1105,7 +1106,7 @@ TEST(Frame, ParseRejectsWindowUpdateFrameZeroIncrement) {
                     /* Stream Identifier (31 bits) */ 0x7f, 0xff, 0xff, 0xff,
                     /* Window Size Increment (31 bits) */ 0, 0, 0, 0),
       Http2StatusIs(
-          Http2Status::Http2ErrorType::kStreamError,
+          Http2Status::Http2ErrorType::kConnectionError,
           Http2ErrorCode::kProtocolError,
           absl::StrCat(
               RFC9113::kWindowSizeIncrement,
@@ -1113,19 +1114,26 @@ TEST(Frame, ParseRejectsWindowUpdateFrameZeroIncrement) {
 }
 
 TEST(Frame, GrpcHeaderTest) {
-  constexpr uint8_t kFlags = 15;
   constexpr uint32_t kLength = 1111111;
 
-  SliceBuffer payload;
-  EXPECT_EQ(payload.Length(), 0);
+  auto verify_header = [](const uint32_t flags, const uint32_t expected_flags,
+                          const uint32_t length) {
+    SliceBuffer payload;
+    EXPECT_EQ(payload.Length(), 0);
+    AppendGrpcHeaderToSliceBuffer(payload, flags, length);
+    EXPECT_EQ(payload.Length(), kGrpcHeaderSizeInBytes);
 
-  AppendGrpcHeaderToSliceBuffer(payload, kFlags, kLength);
-  EXPECT_EQ(payload.Length(), kGrpcHeaderSizeInBytes);
+    ValueOrHttp2Status<GrpcMessageHeader> header = ExtractGrpcHeader(payload);
+    EXPECT_TRUE(header.IsOk());
+    EXPECT_EQ(payload.Length(), kGrpcHeaderSizeInBytes);
+    EXPECT_EQ(header.value().flags, expected_flags);
+    EXPECT_EQ(header.value().length, length);
+  };
 
-  GrpcMessageHeader header = ExtractGrpcHeader(payload);
-  EXPECT_EQ(payload.Length(), kGrpcHeaderSizeInBytes);
-  EXPECT_EQ(header.flags, kFlags);
-  EXPECT_EQ(header.length, kLength);
+  verify_header(/*flags=*/0, /*expected_flags=*/0, kLength);
+  verify_header(/*flags=*/GRPC_WRITE_INTERNAL_COMPRESS,
+                /*expected_flags=*/GRPC_WRITE_INTERNAL_COMPRESS, kLength);
+  verify_header(/*flags=*/10, /*expected_flags=*/0, kLength);
 }
 
 TEST(Frame, ValidateSettingsValuesInvalidInitialWindowSize) {
@@ -1182,20 +1190,29 @@ TEST(Frame, ValidateSettingsValuesValidSettings) {
   EXPECT_TRUE(ValidateSettingsValues(settings).IsOk());
 }
 
-TEST(Frame, ValidateFrameHeaderTest) {
+class ValidateFrameHeaderTest : public ::testing::TestWithParam<bool> {};
+
+TEST_P(ValidateFrameHeaderTest, ValidateFrameHeader) {
+  const bool is_client = GetParam();
+  constexpr uint32_t kLastStreamId = 1;
+
   // Valid frame header
   Http2FrameHeader header{/*length=*/10, /*type=kData */ 0, /*flags=*/0,
                           /*stream_id=*/1};
   EXPECT_TRUE(ValidateFrameHeader(/*max_frame_size_setting=*/100,
                                   /*incoming_header_in_progress=*/false,
-                                  /*incoming_header_stream_id=*/0, header)
+                                  /*incoming_header_stream_id=*/0, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/true)
                   .IsOk());
 
   // Frame size larger than max frame size setting
   header = {/*length=*/101, /*type=kData */ 0, /*flags=*/0, /*stream_id=*/1};
   EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
                                   /*incoming_header_in_progress=*/false,
-                                  /*incoming_header_stream_id=*/0, header),
+                                  /*incoming_header_stream_id=*/0, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/true),
               Http2StatusIs(
                   Http2Status::Http2ErrorType::kConnectionError,
                   Http2ErrorCode::kFrameSizeError,
@@ -1206,7 +1223,9 @@ TEST(Frame, ValidateFrameHeaderTest) {
   header = {/*length=*/10, /*type=kData */ 0, /*flags=*/0, /*stream_id=*/1};
   EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
                                   /*incoming_header_in_progress=*/true,
-                                  /*incoming_header_stream_id=*/1, header),
+                                  /*incoming_header_stream_id=*/1, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/true),
               Http2StatusIs(Http2Status::Http2ErrorType::kConnectionError,
                             Http2ErrorCode::kProtocolError,
                             RFC9113::kAssemblerContiguousSequenceError));
@@ -1216,7 +1235,9 @@ TEST(Frame, ValidateFrameHeaderTest) {
             /*stream_id=*/3};
   EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
                                   /*incoming_header_in_progress=*/true,
-                                  /*incoming_header_stream_id=*/1, header),
+                                  /*incoming_header_stream_id=*/1, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/true),
               Http2StatusIs(Http2Status::Http2ErrorType::kConnectionError,
                             Http2ErrorCode::kProtocolError,
                             RFC9113::kAssemblerContiguousSequenceError));
@@ -1226,8 +1247,133 @@ TEST(Frame, ValidateFrameHeaderTest) {
             /*stream_id=*/1};
   EXPECT_TRUE(ValidateFrameHeader(/*max_frame_size_setting=*/100,
                                   /*incoming_header_in_progress=*/true,
-                                  /*incoming_header_stream_id=*/1, header)
+                                  /*incoming_header_stream_id=*/1, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/true)
                   .IsOk());
+
+  if (is_client) {
+    // Received a data frame with a stream id larger than the last stream id
+    // sent
+    header = {/*length=*/10, /*type=kData*/ 0, /*flags=*/0, /*stream_id=*/5};
+    EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
+                                    /*incoming_header_in_progress=*/false,
+                                    /*incoming_header_stream_id=*/0, header,
+                                    kLastStreamId, is_client,
+                                    /*is_first_settings_processed=*/true),
+                Http2StatusIs(Http2Status::Http2ErrorType::kConnectionError,
+                              Http2ErrorCode::kProtocolError,
+                              RFC9113::kUnknownStreamId));
+  }
+
+  // If first settings frame is not received, and we receive a data frame,
+  // it is a protocol error.
+  header = {/*length=*/10, /*type=kData*/ 0, /*flags=*/0, /*stream_id=*/1};
+  EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
+                                  /*incoming_header_in_progress=*/false,
+                                  /*incoming_header_stream_id=*/0, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/false),
+              Http2StatusIs(Http2Status::Http2ErrorType::kConnectionError,
+                            Http2ErrorCode::kProtocolError,
+                            is_client ? RFC9113::kFirstSettingsFrameClient
+                                      : RFC9113::kFirstSettingsFrameServer));
+
+  // If first settings frame is not processed, and we receive a SETTINGS frame,
+  // it is valid.
+  header = {/*length=*/0, /*type=kSettings*/ 4, /*flags=*/0, /*stream_id=*/0};
+  EXPECT_TRUE(ValidateFrameHeader(/*max_frame_size_setting=*/100,
+                                  /*incoming_header_in_progress=*/false,
+                                  /*incoming_header_stream_id=*/0, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/false)
+                  .IsOk());
+  // If first settings frame is not processed, and we receive a SETTINGS ACK
+  // frame, it is NOT valid.
+  header = {/*length=*/0, /*type=kSettings*/ 4, /*flags=*/1, /*stream_id=*/0};
+  EXPECT_THAT(ValidateFrameHeader(/*max_frame_size_setting=*/100,
+                                  /*incoming_header_in_progress=*/false,
+                                  /*incoming_header_stream_id=*/0, header,
+                                  kLastStreamId, is_client,
+                                  /*is_first_settings_processed=*/false),
+              Http2StatusIs(Http2Status::Http2ErrorType::kConnectionError,
+                            Http2ErrorCode::kProtocolError,
+                            is_client ? RFC9113::kFirstSettingsFrameClient
+                                      : RFC9113::kFirstSettingsFrameServer));
+}
+
+INSTANTIATE_TEST_SUITE_P(ValidateFrameHeader, ValidateFrameHeaderTest,
+                         ::testing::Bool(),
+                         [](const ::testing::TestParamInfo<bool>& info) {
+                           return info.param ? "Client" : "Server";
+                         });
+
+TEST(FrameSize, Http2FrameSizeTest) {
+  constexpr absl::string_view kPayload = "hello";
+  constexpr size_t kPayloadSize = kPayload.size();
+  EXPECT_EQ(GetFrameMemoryUsage(
+                Http2DataFrame{/*stream_id=*/1, /*end_stream=*/false,
+                               /*payload=*/SliceBufferFromString(kPayload)}),
+            sizeof(Http2DataFrame) + kPayloadSize);
+  EXPECT_EQ(GetFrameMemoryUsage(Http2HeaderFrame{
+                /*stream_id=*/1, /*end_headers=*/false, /*end_stream=*/false,
+                /*payload=*/SliceBufferFromString(kPayload)}),
+            sizeof(Http2HeaderFrame) + kPayloadSize);
+  EXPECT_EQ(GetFrameMemoryUsage(Http2ContinuationFrame{
+                /*stream_id=*/1, /*end_headers=*/false,
+                /*payload=*/SliceBufferFromString(kPayload)}),
+            sizeof(Http2ContinuationFrame) + kPayloadSize);
+  EXPECT_EQ(
+      GetFrameMemoryUsage(Http2RstStreamFrame{
+          /*stream_id=*/1,
+          /*error_code=*/static_cast<uint32_t>(Http2ErrorCode::kConnectError)}),
+      sizeof(Http2RstStreamFrame));
+  EXPECT_EQ(GetFrameMemoryUsage(Http2SettingsFrame{}),
+            sizeof(Http2SettingsFrame));
+  EXPECT_EQ(
+      GetFrameMemoryUsage(Http2SettingsFrame{
+          /*ack=*/false,
+          /*settings=*/{{/*id=*/0x1234, /*value=*/0x9abcdef0},
+                        {/*id=*/0x5678, /*value=*/0x12345678}}}),
+      sizeof(Http2SettingsFrame) + (2 * sizeof(Http2SettingsFrame::Setting)));
+  EXPECT_EQ(GetFrameMemoryUsage(
+                Http2PingFrame{/*ack=*/false, /*opaque=*/0x123456789abcdef0}),
+            sizeof(Http2PingFrame));
+  EXPECT_EQ(GetFrameMemoryUsage(Http2GoawayFrame{
+                /*last_stream_id=*/0x12345678,
+                /*error_code=*/
+                static_cast<uint32_t>(Http2ErrorCode::kEnhanceYourCalm),
+                /*debug_data=*/Slice::FromCopiedString(kPayload)}),
+            sizeof(Http2GoawayFrame) + kPayloadSize);
+  EXPECT_EQ(GetFrameMemoryUsage(Http2WindowUpdateFrame{/*stream_id=*/1,
+                                                       /*increment=*/12345678}),
+            sizeof(Http2WindowUpdateFrame));
+  EXPECT_EQ(GetFrameMemoryUsage(Http2SecurityFrame{
+                /*payload=*/SliceBufferFromString(kPayload)}),
+            sizeof(Http2SecurityFrame) + kPayloadSize);
+  EXPECT_EQ(GetFrameMemoryUsage(Http2EmptyFrame{}), sizeof(Http2EmptyFrame));
+}
+
+TEST(MaybeTruncatePayloadTest, Truncation) {
+  // Test with an empty buffer.
+  SliceBuffer sb_empty;
+  EXPECT_EQ(MaybeTruncatePayload(sb_empty, 10), "");
+
+  // Test with a non-empty buffer.
+  SliceBuffer sb;
+  sb.Append(Slice::FromCopiedString("hello world"));
+  // Case: Length > payload length.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 20), "hello world");
+  // Case: Length == payload length + 1.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 12), "hello world");
+  // Case: Length == payload length.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 11), "hello world");
+  // Case: Length == payload length - 1.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 10), "hello worl<clipped>");
+  // Case: Length < payload length.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 5), "hello<clipped>");
+  // Case: Length == 0.
+  EXPECT_EQ(MaybeTruncatePayload(sb, 0), "<clipped>");
 }
 
 }  // namespace
