@@ -17,9 +17,8 @@
 //
 #include "src/core/ext/transport/chttp2/transport/ping_promise.h"
 
-#include "absl/log/log.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
+#include <utility>
+
 #include "src/core/config/core_configuration.h"
 #include "src/core/lib/promise/map.h"
 #include "src/core/lib/promise/party.h"
@@ -29,31 +28,26 @@
 #include "src/core/util/ref_counted_ptr.h"
 #include "src/core/util/time.h"
 #include "test/core/call/yodel/yodel_test.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "absl/log/log.h"
 
 namespace grpc_core {
 
+namespace {
 using ::grpc_core::http2::PingInterface;
 using ::grpc_core::http2::PingManager;
 using ::testing::MockFunction;
 using ::testing::StrictMock;
-using ::testing::WithArgs;
+constexpr Duration kInterval = Duration::Seconds(10);
+constexpr Duration kLongInterval = Duration::Hours(1);
+constexpr Duration kShortInterval = Duration::Seconds(1);
 
 class MockPingInterface : public PingInterface {
  public:
-  MOCK_METHOD(Promise<absl::Status>, SendPing, (SendPingArgs args), (override));
   MOCK_METHOD(Promise<absl::Status>, TriggerWrite, (), (override));
   MOCK_METHOD(Promise<absl::Status>, PingTimeout, (), (override));
 
-  void ExpectSendPing(SendPingArgs expected_args) {
-    EXPECT_CALL(*this, SendPing)
-        .WillOnce(WithArgs<0>([expected_args](SendPingArgs args) {
-          EXPECT_EQ(expected_args.ack, args.ack);
-          LOG(INFO) << "MockPingInterface SendPing Polled (ack: " << args.ack
-                    << " opaque_data: " << args.opaque_data << ")."
-                    << "Expected (ack: " << expected_args.ack << ")";
-          return Immediate(absl::OkStatus());
-        }));
-  }
   void ExpectPingTimeout() {
     EXPECT_CALL(*this, PingTimeout).WillOnce(([]() {
       LOG(INFO) << "MockPingInterface PingTimeout Polled";
@@ -65,35 +59,10 @@ class MockPingInterface : public PingInterface {
       return Immediate(absl::OkStatus());
     }));
   }
-  auto ExpectSendPingReturnArgs(SendPingArgs expected_args) {
-    struct SendPingReturn {
-      SendPingArgs args;
-      Notification ready;
-    };
-    std::shared_ptr<SendPingReturn> send_ping_return =
-        std::make_shared<SendPingReturn>();
-
-    EXPECT_CALL(*this, SendPing)
-        .WillOnce(WithArgs<0>([send_ping_return,
-                               expected_args](SendPingArgs args) {
-          LOG(INFO) << "MockPingInterface SendPing Polled (ack: " << args.ack
-                    << " opaque_data: " << args.opaque_data << ")."
-                    << "Expected (ack: " << expected_args.ack << ")";
-          EXPECT_EQ(expected_args.ack, args.ack);
-          send_ping_return->args = args;
-          send_ping_return->ready.Notify();
-          return Immediate(absl::OkStatus());
-        }));
-    return [send_ping_return] {
-      send_ping_return->ready.WaitForNotification();
-      return send_ping_return->args;
-    };
-  }
 };
 
 class PingManagerTest : public YodelTest {
  protected:
-  using SendPingArgs = PingInterface::SendPingArgs;
   using YodelTest::YodelTest;
 
   Party* GetParty() { return party_.get(); }
@@ -128,12 +97,32 @@ class PingManagerTest : public YodelTest {
 
   RefCountedPtr<Party> party_;
 };
-#define PING_SYSTEM_TEST(name) YODEL_TEST(PingManagerTest, name)
 
-PING_SYSTEM_TEST(NoOp) {}
+void MaybeSendPing(PingManager& ping_system,
+                   Duration next_allowed_ping_interval) {
+  SliceBuffer output_buf;
+  ping_system.MaybeGetSerializedPingFrames(output_buf,
+                                           next_allowed_ping_interval);
+  ping_system.NotifyPingSent();
+}
+
+std::optional<uint64_t> MaybeSendPingAndReturnID(
+    PingManager& ping_system, Duration next_allowed_ping_interval) {
+  SliceBuffer output_buf;
+  std::optional<uint64_t> opaque_data =
+      ping_system.TestOnlyMaybeGetSerializedPingFrames(
+          output_buf, next_allowed_ping_interval);
+  ping_system.NotifyPingSent();
+  return opaque_data;
+}
+}  // namespace
+
+#define PING_MANAGER_TEST(name) YODEL_TEST(PingManagerTest, name)
+
+PING_MANAGER_TEST(NoOp) {}
 
 // Promise based ping callbacks tests
-PING_SYSTEM_TEST(TestPingRequest) {
+PING_MANAGER_TEST(TestPingRequest) {
   // Test to spawn a promise waiting for a ping ack and trigger a ping ack.
   // This test asserts the following:
   // 1. Ping request promise is resolved on getting a ping ack with the same
@@ -143,8 +132,8 @@ PING_SYSTEM_TEST(TestPingRequest) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), kInterval,
+                          std::move(ping_interface), event_engine());
   std::string execution_order;
   StrictMock<MockFunction<void(absl::Status)>> on_done;
 
@@ -188,7 +177,7 @@ PING_SYSTEM_TEST(TestPingRequest) {
   EXPECT_STREQ(execution_order.c_str(), "1234");
 }
 
-PING_SYSTEM_TEST(TestPingUnrelatedAck) {
+PING_MANAGER_TEST(TestPingUnrelatedAck) {
   // Test to spawn a promise waiting for a ping ack and trigger two ping acks,
   // one with an unrelated id and one with the correct id. This test asserts the
   // following:
@@ -198,8 +187,8 @@ PING_SYSTEM_TEST(TestPingUnrelatedAck) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), kInterval,
+                          std::move(ping_interface), event_engine());
   std::string execution_order;
   StrictMock<MockFunction<void(absl::Status)>> on_done;
 
@@ -249,7 +238,7 @@ PING_SYSTEM_TEST(TestPingUnrelatedAck) {
   EXPECT_STREQ(execution_order.c_str(), "12345");
 }
 
-PING_SYSTEM_TEST(TestPingWaitForAck) {
+PING_MANAGER_TEST(TestPingWaitForAck) {
   // Test to spawn a promise waiting for a ping ack and trigger a ping ack.
   // This test asserts the following:
   // 1. Ping request promise is resolved on getting a ping ack with the same
@@ -259,8 +248,8 @@ PING_SYSTEM_TEST(TestPingWaitForAck) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), kInterval,
+                          std::move(ping_interface), event_engine());
   std::string execution_order;
   StrictMock<MockFunction<void(absl::Status)>> on_done;
 
@@ -298,7 +287,7 @@ PING_SYSTEM_TEST(TestPingWaitForAck) {
   EXPECT_STREQ(execution_order.c_str(), "1342");
 }
 
-PING_SYSTEM_TEST(TestPingCancel) {
+PING_MANAGER_TEST(TestPingCancel) {
   // Test to spawn a promise waiting for a ping ack and cancel it. This test
   // asserts the following:
   // 1. There are no outstanding requests for ping.
@@ -306,8 +295,8 @@ PING_SYSTEM_TEST(TestPingCancel) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), kInterval,
+                          std::move(ping_interface), event_engine());
 
   auto party = GetParty();
   EXPECT_EQ(ping_system.CountPingInflight(), 0);
@@ -331,7 +320,7 @@ PING_SYSTEM_TEST(TestPingCancel) {
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(TestPingManagerNoAck) {
+PING_MANAGER_TEST(TestPingManagerNoAck) {
   // Test to trigger a ping request for which no ack is received.
   // This test asserts the following:
   // 1. The ping timeout is triggered after the ping timeout duration.
@@ -339,11 +328,10 @@ PING_SYSTEM_TEST(TestPingManagerNoAck) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  ping_interface->ExpectSendPing(SendPingArgs{false, /*not used*/ 1234});
   ping_interface->ExpectPingTimeout();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), kInterval,
+                          std::move(ping_interface), event_engine());
   auto party = GetParty();
   party->Spawn(
       "PingRequest",
@@ -359,10 +347,8 @@ PING_SYSTEM_TEST(TestPingManagerNoAck) {
   party->Spawn(
       "PingManager",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Seconds(100),
-                                         /*ping_timeout=*/Duration::Seconds(
-                                             10));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      Duration::Seconds(100));
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
 
@@ -371,7 +357,7 @@ PING_SYSTEM_TEST(TestPingManagerNoAck) {
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
+PING_MANAGER_TEST(DISABLED_TestPingManagerDelayedPing) {
   // Test to trigger two ping requests.
   // The test asserts the following:
   // 1. The first ping is sent successfully.
@@ -386,7 +372,6 @@ PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  ping_interface->ExpectSendPing(SendPingArgs{false, 1234});
   ping_interface->ExpectPingTimeout();
 
   // Delayed ping
@@ -394,8 +379,8 @@ PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
 
   auto channel_args =
       GetChannelArgs().Set(GRPC_ARG_HTTP2_MAX_INFLIGHT_PINGS, 2);
-  PingManager ping_system(channel_args, std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(channel_args, /*ping_timeout=*/Duration::Seconds(100),
+                          std::move(ping_interface), event_engine());
   auto party = GetParty();
 
   // Ping 1
@@ -412,10 +397,8 @@ PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
   party->Spawn(
       "PingManager",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Hours(1),
-                                         /*ping_timeout=*/Duration::Seconds(
-                                             100));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      kLongInterval);
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
 
@@ -433,19 +416,15 @@ PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
   party->Spawn(
       "PingManager2",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Hours(1),
-                                         /*ping_timeout=*/Duration::Seconds(
-                                             100));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      kLongInterval);
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
   party->Spawn(
       "PingManager3",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Hours(1),
-                                         /*ping_timeout=*/Duration::Seconds(
-                                             100));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      kLongInterval);
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
 
@@ -454,7 +433,7 @@ PING_SYSTEM_TEST(DISABLED_TestPingManagerDelayedPing) {
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(TestPingManagerAck) {
+PING_MANAGER_TEST(TestPingManagerAck) {
   // Simple test to trigger a ping request and process a ping ack.
   // The test asserts the following:
   // 1. The ping request promise is resolved on getting a ping ack with the same
@@ -464,47 +443,53 @@ PING_SYSTEM_TEST(TestPingManagerAck) {
   InitParty();
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
+  StrictMock<MockFunction<void()>> on_ping_ack_received;
+  EXPECT_CALL(on_ping_ack_received, Call());
 
-  auto cb = ping_interface->ExpectSendPingReturnArgs(SendPingArgs{false, 1234});
-
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(), /*ping_timeout=*/kLongInterval,
+                          std::move(ping_interface), event_engine());
   auto party = GetParty();
+  uint64_t opaque_data;
 
   party->Spawn(
       "PingRequest",
       TrySeq(ping_system.RequestPing(
                  []() { LOG(INFO) << "Ping requested. Waiting for ack."; },
                  /*important*/ false),
-             []() { return absl::OkStatus(); }),
+             [&on_ping_ack_received]() {
+               on_ping_ack_received.Call();
+               return absl::OkStatus();
+             }),
       [](auto) { LOG(INFO) << "Reached PingRequest end"; });
 
   party->Spawn(
       "PingManager",
-      [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Seconds(100),
-                                         /*ping_timeout=*/
-                                         Duration::Hours(1));
+      [&ping_system, &opaque_data] {
+        std::optional<uint64_t> recv_opaque_data = MaybeSendPingAndReturnID(
+            ping_system, /*next_allowed_ping_interval=*/
+            Duration::Seconds(100));
+        EXPECT_TRUE(recv_opaque_data.has_value());
+        opaque_data = recv_opaque_data.value();
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
 
-  party->Spawn("PingAckReceived",
-               TrySeq(Sleep(Duration::Seconds(1)),
-                      Map(
-                          [&ping_system, &cb] {
-                            auto args = cb();
-                            return ping_system.AckPing(args.opaque_data);
-                          },
-                          [](bool) { return absl::OkStatus(); })),
-               [](auto) { LOG(INFO) << "Reached PingAckReceived end"; });
+  party->Spawn(
+      "PingAckReceived",
+      TrySeq(Sleep(kShortInterval),
+             Map([&ping_system,
+                  &opaque_data] { return ping_system.AckPing(opaque_data); },
+                 [](bool result) {
+                   EXPECT_TRUE(result);
+                   return absl::OkStatus();
+                 })),
+      [](auto) { LOG(INFO) << "Reached PingAckReceived end"; });
 
   WaitForAllPendingWork();
   event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(TestPingManagerDelayedAck) {
+PING_MANAGER_TEST(TestPingManagerDelayedAck) {
   // Test to trigger a ping request and process a ping ack after ping timeout.
   // The test asserts the following:
   // 1. The ping timeout is triggered after the ping timeout duration. To ensure
@@ -515,13 +500,14 @@ PING_SYSTEM_TEST(TestPingManagerDelayedAck) {
   InitParty();
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
-
-  auto cb = ping_interface->ExpectSendPingReturnArgs(SendPingArgs{false, 1234});
   ping_interface->ExpectPingTimeout();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(),
+                          /*ping_timeout=*/kShortInterval,
+                          std::move(ping_interface), event_engine());
   auto party = GetParty();
+  uint64_t opaque_data;
+
   party->Spawn(
       "PingRequest",
       TrySeq(ping_system.RequestPing(
@@ -532,29 +518,29 @@ PING_SYSTEM_TEST(TestPingManagerDelayedAck) {
 
   party->Spawn(
       "PingManager",
-      [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Seconds(100),
-                                         /*ping_timeout=*/Duration::Seconds(2));
+      [&ping_system, &opaque_data] {
+        std::optional<uint64_t> recv_opaque_data = MaybeSendPingAndReturnID(
+            ping_system, /*next_allowed_ping_interval=*/
+            Duration::Seconds(100));
+        EXPECT_TRUE(recv_opaque_data.has_value());
+        opaque_data = recv_opaque_data.value();
       },
       [](auto) { LOG(INFO) << "Reached PingManager end"; });
 
-  party->Spawn("DelayedPingAckReceived",
-               TrySeq(Sleep(Duration::Hours(1)),
-                      Map(
-                          [&ping_system, &cb] {
-                            auto args = cb();
-                            return ping_system.AckPing(args.opaque_data);
-                          },
-                          [](bool) { return absl::OkStatus(); })),
-               [](auto) { LOG(INFO) << "Reached PingAckReceived end"; });
+  party->Spawn(
+      "DelayedPingAckReceived",
+      TrySeq(Sleep(kLongInterval),
+             Map([&ping_system,
+                  &opaque_data] { return ping_system.AckPing(opaque_data); },
+                 [](bool) { return absl::OkStatus(); })),
+      [](auto) { LOG(INFO) << "Reached PingAckReceived end"; });
 
   WaitForAllPendingWork();
   event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(TestPingManagerNoPingRequest) {
+PING_MANAGER_TEST(TestPingManagerNoPingRequest) {
   // Tests that MaybeSendPing returns immediately if no ping request has been
   // made.
   InitParty();
@@ -562,17 +548,17 @@ PING_SYSTEM_TEST(TestPingManagerNoPingRequest) {
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
 
-  PingManager ping_system(GetChannelArgs(), std::move(ping_interface),
-                          event_engine());
+  PingManager ping_system(GetChannelArgs(),
+                          /*ping_timeout=*/kShortInterval,
+                          std::move(ping_interface), event_engine());
   auto party = GetParty();
   EXPECT_CALL(on_done, Call(absl::OkStatus()));
 
   party->Spawn(
       "PingManager",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Seconds(100),
-                                         /*ping_timeout=*/Duration::Seconds(2));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      Duration::Seconds(100));
       },
       [&on_done](auto) {
         on_done.Call(absl::OkStatus());
@@ -584,7 +570,7 @@ PING_SYSTEM_TEST(TestPingManagerNoPingRequest) {
   event_engine()->UnsetGlobalHooks();
 }
 
-PING_SYSTEM_TEST(TestPingManagerImportantPing) {
+PING_MANAGER_TEST(TestPingManagerImportantPing) {
   // Tests important flag for ping requests. Asserts the following:
   // 1. The important flag is set correctly for the multiple ping requests.
   // 2. Once a ping request is sent out, the important flag is reset.
@@ -594,12 +580,12 @@ PING_SYSTEM_TEST(TestPingManagerImportantPing) {
 
   std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
       std::make_unique<StrictMock<MockPingInterface>>();
-  ping_interface->ExpectSendPing(SendPingArgs{false, 1234});
   ping_interface->ExpectPingTimeout();
 
   PingManager ping_system(
       GetChannelArgs().Set(GRPC_ARG_HTTP2_MAX_INFLIGHT_PINGS, 1),
-      std::move(ping_interface), event_engine());
+      /*ping_timeout=*/Duration::Seconds(100), std::move(ping_interface),
+      event_engine());
 
   EXPECT_CALL(on_done, Call(absl::OkStatus()));
   EXPECT_FALSE(ping_system.PingRequested());
@@ -641,10 +627,8 @@ PING_SYSTEM_TEST(TestPingManagerImportantPing) {
   GetParty()->Spawn(
       "PingManager",
       [&ping_system] {
-        return ping_system.MaybeSendPing(/*next_allowed_ping_interval=*/
-                                         Duration::Seconds(1),
-                                         /*ping_timeout=*/Duration::Seconds(
-                                             100));
+        MaybeSendPing(ping_system, /*next_allowed_ping_interval=*/
+                      kShortInterval);
       },
       [&on_done, &ping_system](auto) {
         on_done.Call(absl::OkStatus());
@@ -658,4 +642,51 @@ PING_SYSTEM_TEST(TestPingManagerImportantPing) {
   event_engine()->UnsetGlobalHooks();
 }
 
+PING_MANAGER_TEST(TestPingManagerPingTimeoutAfterAck) {
+  // Tests the scenario where the ping timeout is triggered after the ping ack
+  // is received. The test asserts the following:
+  // 1. The ping request promise is resolved on getting a ping ack with the same
+  //    opqaue id.
+  InitParty();
+  StrictMock<MockFunction<void()>> on_ping_ack_received;
+  EXPECT_CALL(on_ping_ack_received, Call());
+  std::unique_ptr<StrictMock<MockPingInterface>> ping_interface =
+      std::make_unique<StrictMock<MockPingInterface>>();
+
+  PingManager ping_system(
+      GetChannelArgs().Set(GRPC_ARG_HTTP2_MAX_INFLIGHT_PINGS, 1),
+      /*ping_timeout=*/Duration::Seconds(100), std::move(ping_interface),
+      event_engine());
+  SliceBuffer output_buf;
+
+  SpawnPingRequest(
+      ping_system, /*important=*/false,
+      [] { LOG(INFO) << "Ping1 requested. Waiting for ack."; },
+      [&on_ping_ack_received] {
+        on_ping_ack_received.Call();
+        return absl::OkStatus();
+      });
+
+  GetParty()->Spawn(
+      "PingManager",
+      [&ping_system, &output_buf] {
+        return TrySeq([&ping_system, &output_buf]() {
+          auto recv_opaque_data =
+              ping_system.TestOnlyMaybeGetSerializedPingFrames(
+                  output_buf,
+                  /*next_allowed_ping_interval=*/kShortInterval);
+          EXPECT_TRUE(recv_opaque_data.has_value());
+          uint64_t opaque_data = recv_opaque_data.value();
+          EXPECT_TRUE(ping_system.AckPing(opaque_data));
+          ping_system.NotifyPingSent();
+          return absl::OkStatus();
+        });
+      },
+      [](auto) { LOG(INFO) << "Reached PingManager end"; });
+
+  WaitForAllPendingWork();
+  event_engine()->TickUntilIdle();
+  event_engine()->UnsetGlobalHooks();
+}
+
 }  // namespace grpc_core
