@@ -16,12 +16,45 @@
 //
 //
 
+#include <grpc/event_engine/event_engine.h>
+
+#include <cstdint>
+#include <limits>
+#include <utility>
+#include <variant>
+#include <vector>
+
+#include "src/core/call/message.h"
+#include "src/core/call/metadata.h"
+#include "src/core/call/metadata_batch.h"
+#include "src/core/ext/transport/chttp2/transport/frame.h"
+#include "src/core/ext/transport/chttp2/transport/header_assembler.h"
+#include "src/core/ext/transport/chttp2/transport/hpack_encoder.h"
+#include "src/core/ext/transport/chttp2/transport/hpack_parser.h"
+#include "src/core/ext/transport/chttp2/transport/http2_settings.h"
+#include "src/core/ext/transport/chttp2/transport/http2_status.h"
+#include "src/core/ext/transport/chttp2/transport/message_assembler.h"
+#include "src/core/ext/transport/chttp2/transport/stream_data_queue.h"
+#include "src/core/lib/promise/if.h"
+#include "src/core/lib/promise/loop.h"
+#include "src/core/lib/promise/map.h"
+#include "src/core/lib/promise/party.h"
+#include "src/core/lib/promise/sleep.h"
+#include "src/core/lib/promise/status_flag.h"
+#include "src/core/lib/promise/try_seq.h"
+#include "src/core/lib/resource_quota/arena.h"
+#include "src/core/lib/slice/slice.h"
+#include "src/core/lib/slice/slice_buffer.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
+#include "src/core/util/ref_counted_ptr.h"
+#include "src/core/util/time.h"
+#include "test/core/call/yodel/yodel_test.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-#include "src/core/ext/transport/chttp2/transport/stream_data_queue.h"
-#include "src/core/lib/promise/loop.h"
-#include "src/core/lib/promise/sleep.h"
-#include "test/core/call/yodel/yodel_test.h"
+#include "absl/log/log.h"
+#include "absl/status/status.h"
+#include "absl/strings/string_view.h"
 
 namespace grpc_core {
 
@@ -48,8 +81,9 @@ class SimpleQueueFuzzTest : public YodelTest {
   auto EnqueueAndCheckSuccess(SimpleQueue<int>& queue, int data, int tokens) {
     return Map([&queue, data,
                 tokens]() mutable { return queue.Enqueue(data, tokens); },
-               [](absl::StatusOr<bool> result) {
-                 EXPECT_EQ(result.status(), absl::OkStatus());
+               [data, tokens](bool result) {
+                 LOG(INFO) << "Enqueue done for data with tokens: " << data
+                           << " tokens: " << tokens << " result: " << result;
                });
   }
 
@@ -185,14 +219,15 @@ class StreamDataQueueFuzzTest : public YodelTest {
   class AssembleFrames {
    public:
     explicit AssembleFrames(const uint32_t stream_id,
-                            const bool allow_true_binary_metadata)
-        : header_assembler_(stream_id, allow_true_binary_metadata) {}
+                            const bool allow_true_binary_metadata) {
+      header_assembler_.InitializeStream(stream_id, allow_true_binary_metadata);
+    }
     void operator()(Http2HeaderFrame frame) {
-      auto status = header_assembler_.AppendHeaderFrame(std::move(frame));
+      auto status = header_assembler_.AppendHeaderFrame(frame);
       EXPECT_TRUE(status.IsOk());
     }
     void operator()(Http2ContinuationFrame frame) {
-      auto status = header_assembler_.AppendContinuationFrame(std::move(frame));
+      auto status = header_assembler_.AppendContinuationFrame(frame);
       EXPECT_TRUE(status.IsOk());
     }
     void operator()(Http2DataFrame frame) {
@@ -287,8 +322,9 @@ YODEL_TEST(StreamDataQueueFuzzTest, EnqueueDequeueMultiParty) {
   HPackCompressor encoder;
   StreamDataQueue<ClientMetadataHandle> stream_data_queue(
       /*is_client=*/true,
-      /*stream_id=*/stream_id,
-      /*queue_size=*/queue_size, /*allow_true_binary_metadata=*/true);
+      /*queue_size=*/queue_size);
+  stream_data_queue.SetStreamId(stream_id,
+                                /*allow_true_binary_metadata_peer=*/true);
   std::vector<MessageHandle> messages_to_be_sent = TestMessages(num_messages);
   std::vector<MessageHandle> messages_copy = TestMessages(num_messages);
   std::vector<MessageHandle> dequeued_messages;
@@ -352,9 +388,9 @@ YODEL_TEST(StreamDataQueueFuzzTest, EnqueueDequeueMultiParty) {
             [this, &stream_data_queue, &assembler, &dequeued_messages] {
               typename StreamDataQueue<ClientMetadataHandle>::DequeueResult
                   frames = stream_data_queue.DequeueFrames(
-                      max_tokens, max_frame_length, GetEncoder(),
+                      max_tokens, max_frame_length, /*stream_fc_tokens=*/
+                      std::numeric_limits<uint32_t>::max(), GetEncoder(),
                       /*can_send_reset_stream=*/true);
-
               for (auto& frame : frames.frames) {
                 std::visit(assembler, std::move(frame));
               }
