@@ -22,7 +22,8 @@
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
 
-#include "gtest/gtest.h"
+#include <memory>
+
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/tsi/alts/handshaker/alts_shared_resource.h"
 #include "src/core/tsi/alts/handshaker/alts_tsi_handshaker.h"
@@ -30,14 +31,18 @@
 #include "src/core/tsi/transport_security.h"
 #include "src/core/tsi/transport_security_interface.h"
 #include "src/core/util/env.h"
+#include "src/proto/grpc/gcp/handshaker.upb.h"
 #include "test/core/test_util/test_config.h"
 #include "test/core/tsi/alts/handshaker/alts_handshaker_service_api_test_lib.h"
 #include "upb/mem/arena.hpp"
+#include "gtest/gtest.h"
 
 #define ALTS_HANDSHAKER_CLIENT_TEST_OUT_FRAME "Hello Google"
 #define ALTS_HANDSHAKER_CLIENT_TEST_TARGET_NAME "bigtable.google.api.com"
 #define ALTS_HANDSHAKER_CLIENT_TEST_TARGET_SERVICE_ACCOUNT1 "A@google.com"
 #define ALTS_HANDSHAKER_CLIENT_TEST_TARGET_SERVICE_ACCOUNT2 "B@google.com"
+#define ALTS_HANDSHAKER_SERVER_TRANSPORT_PROTOCOL "bar,foo"
+#define ALTS_HANDSHAKER_CLIENT_TRANSPORT_PROTOCOL "baz,foo"
 #define ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE (64 * 1024)
 
 const char kMaxConcurrentStreamsEnvironmentVariable[] =
@@ -47,6 +52,7 @@ const size_t kMaxRpcVersionMajor = 3;
 const size_t kMaxRpcVersionMinor = 2;
 const size_t kMinRpcVersionMajor = 2;
 const size_t kMinRpcVersionMinor = 1;
+const char kFakeToken[] = "fake_token";
 
 using grpc_core::internal::alts_handshaker_client_get_closure_for_testing;
 using grpc_core::internal::
@@ -59,6 +65,8 @@ using grpc_core::internal::
 using grpc_core::internal::alts_handshaker_client_set_cb_for_testing;
 using grpc_core::internal::alts_handshaker_client_set_grpc_caller_for_testing;
 
+namespace {
+
 typedef struct alts_handshaker_client_test_config {
   grpc_channel* channel;
   grpc_completion_queue* cq;
@@ -67,8 +75,7 @@ typedef struct alts_handshaker_client_test_config {
   grpc_slice out_frame;
 } alts_handshaker_client_test_config;
 
-static void validate_rpc_protocol_versions(
-    const grpc_gcp_RpcProtocolVersions* versions) {
+void ValidateRpcProtocolVersions(const grpc_gcp_RpcProtocolVersions* versions) {
   ASSERT_NE(versions, nullptr);
   const grpc_gcp_RpcProtocolVersions_Version* max_version =
       grpc_gcp_RpcProtocolVersions_max_rpc_version(versions);
@@ -84,9 +91,8 @@ static void validate_rpc_protocol_versions(
             kMinRpcVersionMinor);
 }
 
-static void validate_target_identities(
-    const grpc_gcp_Identity* const* target_identities,
-    size_t target_identities_count) {
+void ValidateTargetIdentities(const grpc_gcp_Identity* const* target_identities,
+                              size_t target_identities_count) {
   ASSERT_EQ(target_identities_count, 2);
   const grpc_gcp_Identity* identity1 = target_identities[1];
   const grpc_gcp_Identity* identity2 = target_identities[0];
@@ -104,8 +110,8 @@ static void validate_target_identities(
 /// Validate if grpc operation data is correctly populated with the fields of
 /// ALTS handshaker client.
 ///
-static bool validate_op(alts_handshaker_client* c, const grpc_op* op,
-                        size_t nops, bool is_start) {
+bool ValidateOp(alts_handshaker_client* c, const grpc_op* op, size_t nops,
+                bool is_start) {
   EXPECT_TRUE(c != nullptr && op != nullptr && nops != 0);
   bool ok = true;
   grpc_op* start_op = const_cast<grpc_op*>(op);
@@ -133,8 +139,8 @@ static bool validate_op(alts_handshaker_client* c, const grpc_op* op,
   return ok;
 }
 
-static grpc_gcp_HandshakerReq* deserialize_handshaker_req(
-    grpc_byte_buffer* buffer, upb_Arena* arena) {
+grpc_gcp_HandshakerReq* DeserializeHandshakerReq(grpc_byte_buffer* buffer,
+                                                 upb_Arena* arena) {
   EXPECT_NE(buffer, nullptr);
   grpc_byte_buffer_reader bbr;
   EXPECT_TRUE(grpc_byte_buffer_reader_init(&bbr, buffer));
@@ -146,7 +152,7 @@ static grpc_gcp_HandshakerReq* deserialize_handshaker_req(
   return req;
 }
 
-static bool is_recv_status_op(const grpc_op* op, size_t nops) {
+bool IsRecvStatusOp(const grpc_op* op, size_t nops) {
   return nops == 1 && op->op == GRPC_OP_RECV_STATUS_ON_CLIENT;
 }
 
@@ -154,35 +160,15 @@ static bool is_recv_status_op(const grpc_op* op, size_t nops) {
 /// A mock grpc_caller used to check if client_start, server_start, and next
 /// operations correctly handle invalid arguments. It should not be called.
 ///
-static grpc_call_error check_must_not_be_called(grpc_call* /*call*/,
-                                                const grpc_op* /*ops*/,
-                                                size_t /*nops*/,
-                                                grpc_closure* /*tag*/) {
+grpc_call_error CheckMustNotBeCalled(grpc_call* /*call*/,
+                                     const grpc_op* /*ops*/, size_t /*nops*/,
+                                     grpc_closure* /*tag*/) {
   abort();
 }
 
-///
-/// A mock grpc_caller used to check correct execution of client_start
-/// operation. It checks if the client_start handshaker request is populated
-/// with correct handshake_security_protocol, application_protocol,
-/// record_protocol and max_frame_size, and op is correctly populated.
-///
-static grpc_call_error check_client_start_success(grpc_call* /*call*/,
-                                                  const grpc_op* op,
-                                                  size_t nops,
-                                                  grpc_closure* closure) {
-  // RECV_STATUS ops are asserted to always succeed
-  if (is_recv_status_op(op, nops)) {
-    return GRPC_CALL_OK;
-  }
-  upb::Arena arena;
-  alts_handshaker_client* client =
-      static_cast<alts_handshaker_client*>(closure->cb_arg);
-  EXPECT_EQ(alts_handshaker_client_get_closure_for_testing(client), closure);
-  grpc_gcp_HandshakerReq* req = deserialize_handshaker_req(
-      alts_handshaker_client_get_send_buffer_for_testing(client), arena.ptr());
-  const grpc_gcp_StartClientHandshakeReq* client_start =
-      grpc_gcp_HandshakerReq_client_start(req);
+void CheckClientHandshakerRequestCommonData(
+    const grpc_gcp_StartClientHandshakeReq* client_start, bool has_token) {
+  ASSERT_NE(client_start, nullptr);
   EXPECT_EQ(grpc_gcp_StartClientHandshakeReq_handshake_security_protocol(
                 client_start),
             grpc_gcp_ALTS);
@@ -192,49 +178,143 @@ static grpc_call_error check_client_start_success(grpc_call* /*call*/,
   EXPECT_TRUE(upb_StringView_IsEqual(
       application_protocols[0],
       upb_StringView_FromString(ALTS_APPLICATION_PROTOCOL)));
-  upb_StringView const* record_protocols =
-      grpc_gcp_StartClientHandshakeReq_record_protocols(client_start, nullptr);
-  EXPECT_TRUE(upb_StringView_IsEqual(
-      record_protocols[0], upb_StringView_FromString(ALTS_RECORD_PROTOCOL)));
   const grpc_gcp_RpcProtocolVersions* rpc_protocol_versions =
       grpc_gcp_StartClientHandshakeReq_rpc_versions(client_start);
-  validate_rpc_protocol_versions(rpc_protocol_versions);
+  ValidateRpcProtocolVersions(rpc_protocol_versions);
   size_t target_identities_count;
   const grpc_gcp_Identity* const* target_identities =
       grpc_gcp_StartClientHandshakeReq_target_identities(
           client_start, &target_identities_count);
-  validate_target_identities(target_identities, target_identities_count);
+  ValidateTargetIdentities(target_identities, target_identities_count);
   EXPECT_TRUE(upb_StringView_IsEqual(
       grpc_gcp_StartClientHandshakeReq_target_name(client_start),
       upb_StringView_FromString(ALTS_HANDSHAKER_CLIENT_TEST_TARGET_NAME)));
   EXPECT_EQ(grpc_gcp_StartClientHandshakeReq_max_frame_size(client_start),
             ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE);
-  EXPECT_TRUE(validate_op(client, op, nops, true /* is_start */));
-  return GRPC_CALL_OK;
+  if (has_token) {
+    EXPECT_TRUE(upb_StringView_IsEqual(
+        grpc_gcp_StartClientHandshakeReq_access_token(client_start),
+        upb_StringView_FromString(kFakeToken)));
+  }
+}
+
+void VerifyTransportProtocolPreferences(
+    const grpc_gcp_TransportProtocolPreferences* protocol_preferences,
+    bool is_server) {
+  ASSERT_NE(protocol_preferences, nullptr);
+  size_t transport_protocol_count;
+  const upb_StringView* transport_protocols =
+      grpc_gcp_TransportProtocolPreferences_transport_protocol(
+          protocol_preferences, &transport_protocol_count);
+
+  ASSERT_EQ(transport_protocol_count, 2);
+
+  if (is_server) {
+    ASSERT_TRUE(upb_StringView_IsEqual(transport_protocols[0],
+                                       upb_StringView_FromString("bar")));
+  } else {
+    ASSERT_TRUE(upb_StringView_IsEqual(transport_protocols[0],
+                                       upb_StringView_FromString("baz")));
+  }
+  ASSERT_TRUE(upb_StringView_IsEqual(transport_protocols[1],
+                                     upb_StringView_FromString("foo")));
+}
+
+void VerifyCustomRecordProtocolPreferences(
+    upb_StringView const* record_protocols, size_t record_protocol_count) {
+  ASSERT_EQ(record_protocol_count, 2);
+
+  ASSERT_TRUE(upb_StringView_IsEqual(record_protocols[0],
+                                     upb_StringView_FromString("bar")));
+  ASSERT_TRUE(upb_StringView_IsEqual(record_protocols[1],
+                                     upb_StringView_FromString("foo")));
+}
+
+void VerifyDefaultRecordProtocolPreferences(
+    upb_StringView const* record_protocols, size_t record_protocol_count) {
+  ASSERT_EQ(record_protocol_count, 1);
+
+  ASSERT_TRUE(upb_StringView_IsEqual(
+      record_protocols[0], upb_StringView_FromString(ALTS_RECORD_PROTOCOL)));
 }
 
 ///
-/// A mock grpc_caller used to check correct execution of server_start
-/// operation. It checks if the server_start handshaker request is populated
+/// A mock grpc_caller used to check correct execution of client_start
+/// operation. It checks if the client_start handshaker request is populated
 /// with correct handshake_security_protocol, application_protocol,
 /// record_protocol and max_frame_size, and op is correctly populated.
 ///
-static grpc_call_error check_server_start_success(grpc_call* /*call*/,
-                                                  const grpc_op* op,
-                                                  size_t nops,
-                                                  grpc_closure* closure) {
+grpc_call_error CheckClientStartSuccess(grpc_call* /*call*/, const grpc_op* op,
+                                        size_t nops, grpc_closure* closure,
+                                        bool has_token,
+                                        bool has_transport_negotiation = false,
+                                        bool has_record_negotiation = false) {
   // RECV_STATUS ops are asserted to always succeed
-  if (is_recv_status_op(op, nops)) {
+  if (IsRecvStatusOp(op, nops)) {
     return GRPC_CALL_OK;
   }
   upb::Arena arena;
   alts_handshaker_client* client =
       static_cast<alts_handshaker_client*>(closure->cb_arg);
   EXPECT_EQ(alts_handshaker_client_get_closure_for_testing(client), closure);
-  grpc_gcp_HandshakerReq* req = deserialize_handshaker_req(
+  grpc_gcp_HandshakerReq* req = DeserializeHandshakerReq(
       alts_handshaker_client_get_send_buffer_for_testing(client), arena.ptr());
-  const grpc_gcp_StartServerHandshakeReq* server_start =
-      grpc_gcp_HandshakerReq_server_start(req);
+  const grpc_gcp_StartClientHandshakeReq* client_start =
+      grpc_gcp_HandshakerReq_client_start(req);
+  CheckClientHandshakerRequestCommonData(client_start, has_token);
+  EXPECT_TRUE(ValidateOp(client, op, nops, true /* is_start */));
+  if (has_transport_negotiation) {
+    VerifyTransportProtocolPreferences(
+        grpc_gcp_StartClientHandshakeReq_transport_protocol_preferences(
+            client_start),
+        /*is_server=*/false);
+  }
+  size_t record_protocol_count;
+  upb_StringView const* record_protocols =
+      grpc_gcp_StartClientHandshakeReq_record_protocols(client_start,
+                                                        &record_protocol_count);
+  if (has_record_negotiation) {
+    VerifyCustomRecordProtocolPreferences(record_protocols,
+                                          record_protocol_count);
+  } else {
+    VerifyDefaultRecordProtocolPreferences(record_protocols,
+                                           record_protocol_count);
+  }
+  return GRPC_CALL_OK;
+}
+
+grpc_call_error CheckClientStartSuccessWithToken(grpc_call* call,
+                                                 const grpc_op* op, size_t nops,
+                                                 grpc_closure* closure) {
+  return CheckClientStartSuccess(call, op, nops, closure, /*has_token=*/true);
+}
+
+grpc_call_error CheckClientStartSuccessWithoutToken(grpc_call* call,
+                                                    const grpc_op* op,
+                                                    size_t nops,
+                                                    grpc_closure* closure) {
+  return CheckClientStartSuccess(call, op, nops, closure, /*has_token=*/false);
+}
+
+grpc_call_error VerifyClientStartSuccessWithTransportProtocolNegotiation(
+    grpc_call* call, const grpc_op* op, size_t nops, grpc_closure* closure) {
+  return CheckClientStartSuccess(call, op, nops, closure,
+                                 /*has_token=*/false,
+                                 /*has_transport_negotiation= */ true,
+                                 /*has_record_negotiation= */ false);
+}
+
+grpc_call_error VerifyClientStartSuccessWithRecordProtocolNegotiation(
+    grpc_call* call, const grpc_op* op, size_t nops, grpc_closure* closure) {
+  return CheckClientStartSuccess(call, op, nops, closure,
+                                 /*has_token=*/false,
+                                 /*has_transport_negotiation= */ false,
+                                 /*has_record_negotiation= */ true);
+}
+
+void CheckServerHandshakerRequestCommonData(
+    const grpc_gcp_StartServerHandshakeReq* server_start) {
+  ASSERT_NE(server_start, nullptr);
   upb_StringView const* application_protocols =
       grpc_gcp_StartServerHandshakeReq_application_protocols(server_start,
                                                              nullptr);
@@ -244,41 +324,97 @@ static grpc_call_error check_server_start_success(grpc_call* /*call*/,
   EXPECT_EQ(
       grpc_gcp_StartServerHandshakeReq_handshake_parameters_size(server_start),
       1);
-  grpc_gcp_ServerHandshakeParameters* value;
-  EXPECT_TRUE(grpc_gcp_StartServerHandshakeReq_handshake_parameters_get(
-      server_start, grpc_gcp_ALTS, &value));
-  upb_StringView const* record_protocols =
-      grpc_gcp_ServerHandshakeParameters_record_protocols(value, nullptr);
-  EXPECT_TRUE(upb_StringView_IsEqual(
-      record_protocols[0], upb_StringView_FromString(ALTS_RECORD_PROTOCOL)));
-  validate_rpc_protocol_versions(
+  ValidateRpcProtocolVersions(
       grpc_gcp_StartServerHandshakeReq_rpc_versions(server_start));
   EXPECT_EQ(grpc_gcp_StartServerHandshakeReq_max_frame_size(server_start),
             ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE);
-  EXPECT_TRUE(validate_op(client, op, nops, true /* is_start */));
+}
+
+///
+/// A mock grpc_caller used to check correct execution of server_start
+/// operation. It checks if the server_start handshaker request is populated
+/// with correct handshake_security_protocol, application_protocol,
+/// record_protocol and max_frame_size, and op is correctly populated.
+///
+grpc_call_error CheckServerStartSuccess(grpc_call* /*call*/, const grpc_op* op,
+                                        size_t nops, grpc_closure* closure,
+                                        bool has_transport_negotiation = false,
+                                        bool has_record_negotiation = false) {
+  // RECV_STATUS ops are asserted to always succeed
+  if (IsRecvStatusOp(op, nops)) {
+    return GRPC_CALL_OK;
+  }
+  upb::Arena arena;
+  alts_handshaker_client* client =
+      static_cast<alts_handshaker_client*>(closure->cb_arg);
+  EXPECT_EQ(alts_handshaker_client_get_closure_for_testing(client), closure);
+  grpc_gcp_HandshakerReq* req = DeserializeHandshakerReq(
+      alts_handshaker_client_get_send_buffer_for_testing(client), arena.ptr());
+  const grpc_gcp_StartServerHandshakeReq* server_start =
+      grpc_gcp_HandshakerReq_server_start(req);
+  CheckServerHandshakerRequestCommonData(server_start);
+  grpc_gcp_ServerHandshakeParameters* value;
+  EXPECT_TRUE(grpc_gcp_StartServerHandshakeReq_handshake_parameters_get(
+      server_start, grpc_gcp_ALTS, &value));
+  EXPECT_TRUE(ValidateOp(client, op, nops, true /* is_start */));
+  if (has_transport_negotiation) {
+    VerifyTransportProtocolPreferences(
+        grpc_gcp_StartServerHandshakeReq_transport_protocol_preferences(
+            server_start),
+        /*is_server=*/true);
+  }
+  size_t record_protocol_count;
+  upb_StringView const* record_protocols =
+      grpc_gcp_ServerHandshakeParameters_record_protocols(
+          value, &record_protocol_count);
+  if (has_record_negotiation) {
+    VerifyCustomRecordProtocolPreferences(record_protocols,
+                                          record_protocol_count);
+  } else {
+    VerifyDefaultRecordProtocolPreferences(record_protocols,
+                                           record_protocol_count);
+  }
   return GRPC_CALL_OK;
 }
 
+grpc_call_error CheckServerStartSuccessDefault(grpc_call* call,
+                                               const grpc_op* op, size_t nops,
+                                               grpc_closure* closure) {
+  return CheckServerStartSuccess(call, op, nops, closure);
+}
+
+grpc_call_error CheckServerStartSuccessWithTransportProtocolNegotiation(
+    grpc_call* call, const grpc_op* op, size_t nops, grpc_closure* closure) {
+  return CheckServerStartSuccess(call, op, nops, closure,
+                                 /*has_transport_negotiation=*/true);
+}
+
+grpc_call_error VerifyServerStartSuccessWithRecordProtocolNegotiation(
+    grpc_call* call, const grpc_op* op, size_t nops, grpc_closure* closure) {
+  return CheckServerStartSuccess(call, op, nops, closure,
+                                 /*has_transport_negotiation=*/false,
+                                 /*has_record_negotiation=*/true);
+}
+
 ///
 /// A mock grpc_caller used to check correct execution of next operation. It
 /// checks if the next handshaker request is populated with correct information,
 /// and op is correctly populated.
 ///
-static grpc_call_error check_next_success(grpc_call* /*call*/,
-                                          const grpc_op* op, size_t nops,
-                                          grpc_closure* closure) {
+grpc_call_error CheckNextSuccess(grpc_call* /*call*/, const grpc_op* op,
+                                 size_t nops, grpc_closure* closure) {
   upb::Arena arena;
   alts_handshaker_client* client =
       static_cast<alts_handshaker_client*>(closure->cb_arg);
   EXPECT_EQ(alts_handshaker_client_get_closure_for_testing(client), closure);
-  grpc_gcp_HandshakerReq* req = deserialize_handshaker_req(
+  grpc_gcp_HandshakerReq* req = DeserializeHandshakerReq(
       alts_handshaker_client_get_send_buffer_for_testing(client), arena.ptr());
   const grpc_gcp_NextHandshakeMessageReq* next =
       grpc_gcp_HandshakerReq_next(req);
   EXPECT_TRUE(upb_StringView_IsEqual(
       grpc_gcp_NextHandshakeMessageReq_in_bytes(next),
       upb_StringView_FromString(ALTS_HANDSHAKER_CLIENT_TEST_OUT_FRAME)));
-  EXPECT_TRUE(validate_op(client, op, nops, false /* is_start */));
+  EXPECT_TRUE(ValidateOp(client, op, nops, false /* is_start */));
   return GRPC_CALL_OK;
 }
 
@@ -287,18 +423,17 @@ static grpc_call_error check_next_success(grpc_call* /*call*/,
 /// operations correctly handle the situation when the grpc call made to the
 /// handshaker service fails.
 ///
-static grpc_call_error check_grpc_call_failure(grpc_call* /*call*/,
-                                               const grpc_op* op, size_t nops,
-                                               grpc_closure* /*tag*/) {
+grpc_call_error CheckGrpcCallFailure(grpc_call* /*call*/, const grpc_op* op,
+                                     size_t nops, grpc_closure* /*tag*/) {
   // RECV_STATUS ops are asserted to always succeed
-  if (is_recv_status_op(op, nops)) {
+  if (IsRecvStatusOp(op, nops)) {
     return GRPC_CALL_OK;
   }
   return GRPC_CALL_ERROR;
 }
 
-static grpc_alts_credentials_options* create_credentials_options(
-    bool is_client) {
+grpc_alts_credentials_options* CreateCredentialsOptions(
+    bool is_client, bool add_custom_record_protocol) {
   grpc_alts_credentials_options* options =
       is_client ? grpc_alts_credentials_client_options_create()
                 : grpc_alts_credentials_server_options_create();
@@ -313,10 +448,16 @@ static grpc_alts_credentials_options* create_credentials_options(
       versions, kMaxRpcVersionMajor, kMaxRpcVersionMinor));
   EXPECT_TRUE(grpc_gcp_rpc_protocol_versions_set_min(
       versions, kMinRpcVersionMajor, kMinRpcVersionMinor));
+
+  if (add_custom_record_protocol) {
+    options->record_protocols = {"bar", "foo"};
+  }
   return options;
 }
 
-static alts_handshaker_client_test_config* create_config() {
+alts_handshaker_client_test_config* CreateConfig(
+    bool add_custom_record_protocol = false,
+    std::shared_ptr<grpc::alts::TokenFetcher> token_fetcher = nullptr) {
   alts_handshaker_client_test_config* config =
       static_cast<alts_handshaker_client_test_config*>(
           gpr_zalloc(sizeof(*config)));
@@ -325,22 +466,28 @@ static alts_handshaker_client_test_config* create_config() {
                                         creds, nullptr);
   grpc_channel_credentials_release(creds);
   config->cq = grpc_completion_queue_create_for_next(nullptr);
-  grpc_alts_credentials_options* client_options =
-      create_credentials_options(true /* is_client */);
-  grpc_alts_credentials_options* server_options =
-      create_credentials_options(false /*  is_client */);
+  grpc_alts_credentials_options* client_options = CreateCredentialsOptions(
+      true /* is_client */, add_custom_record_protocol);
+  grpc_alts_credentials_options* server_options = CreateCredentialsOptions(
+      false /*  is_client */, add_custom_record_protocol);
+  if (token_fetcher != nullptr) {
+    grpc_alts_credentials_client_options_set_token_fetcher(client_options,
+                                                           token_fetcher);
+  }
   config->server = alts_grpc_handshaker_client_create(
       nullptr, config->channel, ALTS_HANDSHAKER_SERVICE_URL_FOR_TESTING,
       nullptr, server_options,
       grpc_slice_from_static_string(ALTS_HANDSHAKER_CLIENT_TEST_TARGET_NAME),
       nullptr, nullptr, nullptr, nullptr, false,
-      ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE, nullptr);
+      ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE,
+      ALTS_HANDSHAKER_SERVER_TRANSPORT_PROTOCOL, nullptr);
   config->client = alts_grpc_handshaker_client_create(
       nullptr, config->channel, ALTS_HANDSHAKER_SERVICE_URL_FOR_TESTING,
       nullptr, client_options,
       grpc_slice_from_static_string(ALTS_HANDSHAKER_CLIENT_TEST_TARGET_NAME),
       nullptr, nullptr, nullptr, nullptr, true,
-      ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE, nullptr);
+      ALTS_HANDSHAKER_CLIENT_TEST_MAX_FRAME_SIZE,
+      ALTS_HANDSHAKER_CLIENT_TRANSPORT_PROTOCOL, nullptr);
   EXPECT_NE(config->client, nullptr);
   EXPECT_NE(config->server, nullptr);
   grpc_alts_credentials_options_destroy(client_options);
@@ -350,7 +497,7 @@ static alts_handshaker_client_test_config* create_config() {
   return config;
 }
 
-static void destroy_config(alts_handshaker_client_test_config* config) {
+void DestroyConfig(alts_handshaker_client_test_config* config) {
   if (config == nullptr) {
     return;
   }
@@ -362,12 +509,31 @@ static void destroy_config(alts_handshaker_client_test_config* config) {
   gpr_free(config);
 }
 
+class FakeTokenFetcher : public grpc::alts::TokenFetcher {
+ public:
+  explicit FakeTokenFetcher(absl::Status error = absl::OkStatus())
+      : error_(std::move(error)) {}
+  ~FakeTokenFetcher() override = default;
+
+  absl::StatusOr<std::string> GetToken() override {
+    if (!error_.ok()) {
+      return error_;
+    }
+    return kFakeToken;
+  }
+
+ private:
+  absl::Status error_;
+};
+
+}  // namespace
+
 TEST(AltsHandshakerClientTest, ScheduleRequestInvalidArgTest) {
   // Initialization.
-  alts_handshaker_client_test_config* config = create_config();
+  alts_handshaker_client_test_config* config = CreateConfig();
   // Tests.
   alts_handshaker_client_set_grpc_caller_for_testing(config->client,
-                                                     check_must_not_be_called);
+                                                     CheckMustNotBeCalled);
   // Check client_start.
   {
     grpc_core::ExecCtx exec_ctx;
@@ -399,15 +565,15 @@ TEST(AltsHandshakerClientTest, ScheduleRequestInvalidArgTest) {
   // Check shutdown.
   alts_handshaker_client_shutdown(nullptr);
   // Cleanup.
-  destroy_config(config);
+  DestroyConfig(config);
 }
 
 TEST(AltsHandshakerClientTest, ScheduleRequestSuccessTest) {
   // Initialization.
-  alts_handshaker_client_test_config* config = create_config();
+  alts_handshaker_client_test_config* config = CreateConfig();
   // Check client_start success.
   alts_handshaker_client_set_grpc_caller_for_testing(
-      config->client, check_client_start_success);
+      config->client, CheckClientStartSuccessWithoutToken);
   {
     grpc_core::ExecCtx exec_ctx;
     ASSERT_EQ(alts_handshaker_client_start_client(config->client), TSI_OK);
@@ -419,7 +585,7 @@ TEST(AltsHandshakerClientTest, ScheduleRequestSuccessTest) {
   }
   // Check server_start success.
   alts_handshaker_client_set_grpc_caller_for_testing(
-      config->server, check_server_start_success);
+      config->server, CheckServerStartSuccessDefault);
   {
     grpc_core::ExecCtx exec_ctx;
     ASSERT_EQ(
@@ -428,7 +594,7 @@ TEST(AltsHandshakerClientTest, ScheduleRequestSuccessTest) {
   }
   // Check client next success.
   alts_handshaker_client_set_grpc_caller_for_testing(config->client,
-                                                     check_next_success);
+                                                     CheckNextSuccess);
   {
     grpc_core::ExecCtx exec_ctx;
     ASSERT_EQ(alts_handshaker_client_next(config->client, &config->out_frame),
@@ -436,7 +602,7 @@ TEST(AltsHandshakerClientTest, ScheduleRequestSuccessTest) {
   }
   // Check server next success.
   alts_handshaker_client_set_grpc_caller_for_testing(config->server,
-                                                     check_next_success);
+                                                     CheckNextSuccess);
   {
     grpc_core::ExecCtx exec_ctx;
     ASSERT_EQ(alts_handshaker_client_next(config->server, &config->out_frame),
@@ -450,7 +616,166 @@ TEST(AltsHandshakerClientTest, ScheduleRequestSuccessTest) {
     alts_handshaker_client_on_status_received_for_testing(
         config->server, GRPC_STATUS_OK, absl::OkStatus());
   }
-  destroy_config(config);
+  DestroyConfig(config);
+}
+
+TEST(AltsHandshakerClientTest, ScheduleRequestWithTokenSuccessTest) {
+  // Initialization.
+  std::shared_ptr<FakeTokenFetcher> token_fetcher =
+      std::make_shared<FakeTokenFetcher>();
+  alts_handshaker_client_test_config* config =
+      CreateConfig(/*add_custom_record_protocol=*/false, token_fetcher);
+  // Check client_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->client, CheckClientStartSuccessWithToken);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_start_client(config->client), TSI_OK);
+  }
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(nullptr, &config->out_frame),
+              TSI_INVALID_ARGUMENT);
+  }
+  // Check server_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->server, CheckServerStartSuccessDefault);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(
+        alts_handshaker_client_start_server(config->server, &config->out_frame),
+        TSI_OK);
+  }
+  // Check client next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->client,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->client, &config->out_frame),
+              TSI_OK);
+  }
+  // Check server next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->server,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->server, &config->out_frame),
+              TSI_OK);
+  }
+  // Cleanup.
+  {
+    grpc_core::ExecCtx exec_ctx;
+    alts_handshaker_client_on_status_received_for_testing(
+        config->client, GRPC_STATUS_OK, absl::OkStatus());
+    alts_handshaker_client_on_status_received_for_testing(
+        config->server, GRPC_STATUS_OK, absl::OkStatus());
+  }
+  DestroyConfig(config);
+}
+
+TEST(AltsHandshakerClientTest,
+     ScheduleRequestSuccessWithTransportProtocolNegotiationTest) {
+  // Initialization.
+  alts_handshaker_client_test_config* config = CreateConfig();
+  // Check client_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->client, VerifyClientStartSuccessWithTransportProtocolNegotiation);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_start_client(config->client), TSI_OK);
+  }
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(nullptr, &config->out_frame),
+              TSI_INVALID_ARGUMENT);
+  }
+  // Check server_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->server, CheckServerStartSuccessWithTransportProtocolNegotiation);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(
+        alts_handshaker_client_start_server(config->server, &config->out_frame),
+        TSI_OK);
+  }
+  // Check client next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->client,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->client, &config->out_frame),
+              TSI_OK);
+  }
+  // Check server next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->server,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->server, &config->out_frame),
+              TSI_OK);
+  }
+  // Cleanup.
+  {
+    grpc_core::ExecCtx exec_ctx;
+    alts_handshaker_client_on_status_received_for_testing(
+        config->client, GRPC_STATUS_OK, absl::OkStatus());
+    alts_handshaker_client_on_status_received_for_testing(
+        config->server, GRPC_STATUS_OK, absl::OkStatus());
+  }
+  DestroyConfig(config);
+}
+
+TEST(AltsHandshakerClientTest,
+     ScheduleRequestSuccessWithRecordProtocolNegotiationTest) {
+  // Initialization.
+  alts_handshaker_client_test_config* config =
+      CreateConfig(true /* add_custom_record_protocol */);
+  // Check client_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->client, VerifyClientStartSuccessWithRecordProtocolNegotiation);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_start_client(config->client), TSI_OK);
+  }
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(nullptr, &config->out_frame),
+              TSI_INVALID_ARGUMENT);
+  }
+  // Check server_start success.
+  alts_handshaker_client_set_grpc_caller_for_testing(
+      config->server, VerifyServerStartSuccessWithRecordProtocolNegotiation);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(
+        alts_handshaker_client_start_server(config->server, &config->out_frame),
+        TSI_OK);
+  }
+  // Check client next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->client,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->client, &config->out_frame),
+              TSI_OK);
+  }
+  // Check server next success.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->server,
+                                                     CheckNextSuccess);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    ASSERT_EQ(alts_handshaker_client_next(config->server, &config->out_frame),
+              TSI_OK);
+  }
+  // Cleanup.
+  {
+    grpc_core::ExecCtx exec_ctx;
+    alts_handshaker_client_on_status_received_for_testing(
+        config->client, GRPC_STATUS_OK, absl::OkStatus());
+    alts_handshaker_client_on_status_received_for_testing(
+        config->server, GRPC_STATUS_OK, absl::OkStatus());
+  }
+  DestroyConfig(config);
 }
 
 static void tsi_cb_assert_tsi_internal_error(
@@ -460,12 +785,34 @@ static void tsi_cb_assert_tsi_internal_error(
   ASSERT_EQ(status, TSI_INTERNAL_ERROR);
 }
 
-TEST(AltsHandshakerClientTest, ScheduleRequestGrpcCallFailureTest) {
+TEST(AltsHandshakerClientTest, ScheduleRequestWithTokenFailureTest) {
   // Initialization.
-  alts_handshaker_client_test_config* config = create_config();
+  std::shared_ptr<FakeTokenFetcher> token_fetcher =
+      std::make_shared<FakeTokenFetcher>(
+          absl::InternalError("failed to get a token"));
+  alts_handshaker_client_test_config* config =
+      CreateConfig(/*add_custom_record_protocol=*/false, token_fetcher);
   // Check client_start failure.
   alts_handshaker_client_set_grpc_caller_for_testing(config->client,
-                                                     check_grpc_call_failure);
+                                                     CheckGrpcCallFailure);
+  {
+    grpc_core::ExecCtx exec_ctx;
+    // TODO(apolcyn): go back to asserting TSI_INTERNAL_ERROR as return
+    // value instead of callback status, after removing the global
+    // queue in https://github.com/grpc/grpc/pull/20722
+    alts_handshaker_client_set_cb_for_testing(config->client,
+                                              tsi_cb_assert_tsi_internal_error);
+    alts_handshaker_client_start_client(config->client);
+  }
+  DestroyConfig(config);
+}
+
+TEST(AltsHandshakerClientTest, ScheduleRequestGrpcCallFailureTest) {
+  // Initialization.
+  alts_handshaker_client_test_config* config = CreateConfig();
+  // Check client_start failure.
+  alts_handshaker_client_set_grpc_caller_for_testing(config->client,
+                                                     CheckGrpcCallFailure);
   {
     grpc_core::ExecCtx exec_ctx;
     // TODO(apolcyn): go back to asserting TSI_INTERNAL_ERROR as return
@@ -477,7 +824,7 @@ TEST(AltsHandshakerClientTest, ScheduleRequestGrpcCallFailureTest) {
   }
   // Check server_start failure.
   alts_handshaker_client_set_grpc_caller_for_testing(config->server,
-                                                     check_grpc_call_failure);
+                                                     CheckGrpcCallFailure);
   {
     grpc_core::ExecCtx exec_ctx;
     // TODO(apolcyn): go back to asserting TSI_INTERNAL_ERROR as return
@@ -507,7 +854,7 @@ TEST(AltsHandshakerClientTest, ScheduleRequestGrpcCallFailureTest) {
     alts_handshaker_client_on_status_received_for_testing(
         config->server, GRPC_STATUS_OK, absl::OkStatus());
   }
-  destroy_config(config);
+  DestroyConfig(config);
 }
 
 TEST(MaxNumberOfConcurrentHandshakesTest, Default) {
