@@ -23,7 +23,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "gtest/gtest.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/tsi/alts/handshaker/alts_handshaker_client.h"
 #include "src/core/tsi/alts/handshaker/alts_shared_resource.h"
@@ -35,7 +34,8 @@
 #include "test/core/tsi/alts/handshaker/alts_handshaker_service_api_test_lib.h"
 #include "upb/base/string_view.h"
 #include "upb/mem/arena.hpp"
-#include "upb/message/internal/map.h"
+#include "upb/message/map.h"
+#include "gtest/gtest.h"
 
 #define ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES "Hello World"
 #define ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME "Hello Google"
@@ -91,6 +91,8 @@ typedef enum {
   SERVER_START,
   CLIENT_NEXT,
   SERVER_NEXT,
+  CLIENT_NEXT_INTEGRITY_ONLY,
+  SERVER_NEXT_INTEGRITY_ONLY,
 } alts_handshaker_response_type;
 
 static alts_handshaker_client* cb_event = nullptr;
@@ -148,6 +150,7 @@ static grpc_byte_buffer* generate_handshaker_response(
           resp, upb_StringView_FromString(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
       break;
     case CLIENT_NEXT:
+    case CLIENT_NEXT_INTEGRITY_ONLY:
       grpc_gcp_HandshakerResp_set_out_frames(
           resp, upb_StringView_FromString(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
       grpc_gcp_HandshakerResp_set_bytes_consumed(
@@ -181,8 +184,10 @@ static grpc_byte_buffer* generate_handshaker_response(
           result, upb_StringView_FromString(
                       ALTS_TSI_HANDSHAKER_TEST_APPLICATION_PROTOCOL));
       grpc_gcp_HandshakerResult_set_record_protocol(
-          result,
-          upb_StringView_FromString(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL));
+          result, upb_StringView_FromString(
+                      type == CLIENT_NEXT_INTEGRITY_ONLY
+                          ? ALTS_INTEGRITY_ONLY_RECORD_PROTOCOL
+                          : ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL));
       grpc_gcp_HandshakerResult_set_max_frame_size(
           result, ALTS_TSI_HANDSHAKER_TEST_MAX_FRAME_SIZE);
       protocol = grpc_gcp_HandshakerResult_mutable_transport_protocol(
@@ -192,6 +197,7 @@ static grpc_byte_buffer* generate_handshaker_response(
                         ALTS_TSI_HANDSHAKER_NEGOTIATED_TRANSPORT_PROTOCOL));
       break;
     case SERVER_NEXT:
+    case SERVER_NEXT_INTEGRITY_ONLY:
       grpc_gcp_HandshakerResp_set_bytes_consumed(
           resp, strlen(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
       result = grpc_gcp_HandshakerResp_mutable_result(resp, arena.ptr());
@@ -223,8 +229,10 @@ static grpc_byte_buffer* generate_handshaker_response(
           result, upb_StringView_FromString(
                       ALTS_TSI_HANDSHAKER_TEST_APPLICATION_PROTOCOL));
       grpc_gcp_HandshakerResult_set_record_protocol(
-          result,
-          upb_StringView_FromString(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL));
+          result, upb_StringView_FromString(
+                      type == SERVER_NEXT_INTEGRITY_ONLY
+                          ? ALTS_INTEGRITY_ONLY_RECORD_PROTOCOL
+                          : ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL));
       protocol = grpc_gcp_HandshakerResult_mutable_transport_protocol(
           result, arena.ptr());
       grpc_gcp_NegotiatedTransportProtocol_set_transport_protocol(
@@ -258,10 +266,10 @@ static void check_must_not_be_called(tsi_result /*status*/, void* /*user_data*/,
   ASSERT_TRUE(0);
 }
 
-static void on_client_start_success_cb(tsi_result status, void* user_data,
-                                       const unsigned char* bytes_to_send,
-                                       size_t bytes_to_send_size,
-                                       tsi_handshaker_result* result) {
+void OnClientStartSuccessCb(tsi_result status, void* user_data,
+                            const unsigned char* bytes_to_send,
+                            size_t bytes_to_send_size,
+                            tsi_handshaker_result* result) {
   ASSERT_EQ(status, TSI_OK);
   ASSERT_EQ(user_data, nullptr);
   ASSERT_EQ(bytes_to_send_size, strlen(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
@@ -287,10 +295,10 @@ static void on_client_start_success_cb(tsi_result status, void* user_data,
   signal(&tsi_to_caller_notification);
 }
 
-static void on_server_start_success_cb(tsi_result status, void* user_data,
-                                       const unsigned char* bytes_to_send,
-                                       size_t bytes_to_send_size,
-                                       tsi_handshaker_result* result) {
+void OnServerStartSuccessCb(tsi_result status, void* user_data,
+                            const unsigned char* bytes_to_send,
+                            size_t bytes_to_send_size,
+                            tsi_handshaker_result* result) {
   ASSERT_EQ(status, TSI_OK);
   ASSERT_EQ(user_data, nullptr);
   ASSERT_EQ(bytes_to_send_size, strlen(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
@@ -316,10 +324,11 @@ static void on_server_start_success_cb(tsi_result status, void* user_data,
   signal(&tsi_to_caller_notification);
 }
 
-static void on_client_next_success_cb(tsi_result status, void* user_data,
-                                      const unsigned char* bytes_to_send,
-                                      size_t bytes_to_send_size,
-                                      tsi_handshaker_result* result) {
+void OnClientNextSuccessBase(tsi_result status, void* user_data,
+                             const unsigned char* bytes_to_send,
+                             size_t bytes_to_send_size,
+                             tsi_handshaker_result* result,
+                             bool is_integrity_only) {
   ASSERT_EQ(status, TSI_OK);
   ASSERT_EQ(user_data, nullptr);
   ASSERT_EQ(bytes_to_send_size, strlen(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME));
@@ -365,9 +374,15 @@ static void on_client_next_success_cb(tsi_result status, void* user_data,
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_APPLICATION_PROTOCOL,
                    application_protocol.data, application_protocol.size),
             0);
-  ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL,
-                   record_protocol.data, record_protocol.size),
-            0);
+  if (is_integrity_only) {
+    ASSERT_EQ(memcmp(ALTS_INTEGRITY_ONLY_RECORD_PROTOCOL, record_protocol.data,
+                     record_protocol.size),
+              0);
+  } else {
+    ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL,
+                     record_protocol.data, record_protocol.size),
+              0);
+  }
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_PEER_IDENTITY, peer_account.data,
                    peer_account.size),
             0);
@@ -387,10 +402,18 @@ static void on_client_next_success_cb(tsi_result status, void* user_data,
   }
 
   // Validate security level.
-  ASSERT_EQ(
-      memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
-             peer.properties[4].value.data, peer.properties[4].value.length),
-      0);
+  if (is_integrity_only) {
+    ASSERT_EQ(
+        memcmp(tsi_security_level_to_string(TSI_INTEGRITY_ONLY),
+               peer.properties[4].value.data, peer.properties[4].value.length),
+        0);
+  } else {
+    ASSERT_EQ(
+        memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
+               peer.properties[4].value.data, peer.properties[4].value.length),
+        0);
+  }
+
   tsi_peer_destruct(&peer);
   // Validate unused bytes.
   const unsigned char* bytes = nullptr;
@@ -411,10 +434,29 @@ static void on_client_next_success_cb(tsi_result status, void* user_data,
   signal(&tsi_to_caller_notification);
 }
 
-static void on_server_next_success_cb(tsi_result status, void* user_data,
-                                      const unsigned char* bytes_to_send,
-                                      size_t bytes_to_send_size,
-                                      tsi_handshaker_result* result) {
+void OnClientNextSuccessCb(tsi_result status, void* user_data,
+                           const unsigned char* bytes_to_send,
+                           size_t bytes_to_send_size,
+                           tsi_handshaker_result* result) {
+  return OnClientNextSuccessBase(status, user_data, bytes_to_send,
+                                 bytes_to_send_size, result,
+                                 /*is_integrity_only=*/false);
+}
+
+void OnClientNextSuccessIntegrityOnlyCb(tsi_result status, void* user_data,
+                                        const unsigned char* bytes_to_send,
+                                        size_t bytes_to_send_size,
+                                        tsi_handshaker_result* result) {
+  return OnClientNextSuccessBase(status, user_data, bytes_to_send,
+                                 bytes_to_send_size, result,
+                                 /*is_integrity_only=*/true);
+}
+
+void OnServerNextSuccessBase(tsi_result status, void* user_data,
+                             const unsigned char* bytes_to_send,
+                             size_t bytes_to_send_size,
+                             tsi_handshaker_result* result,
+                             bool is_integrity_only = false) {
   ASSERT_EQ(status, TSI_OK);
   ASSERT_EQ(user_data, nullptr);
   ASSERT_EQ(bytes_to_send_size, 0);
@@ -460,9 +502,15 @@ static void on_server_next_success_cb(tsi_result status, void* user_data,
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_APPLICATION_PROTOCOL,
                    application_protocol.data, application_protocol.size),
             0);
-  ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL,
-                   record_protocol.data, record_protocol.size),
-            0);
+  if (is_integrity_only) {
+    ASSERT_EQ(memcmp(ALTS_INTEGRITY_ONLY_RECORD_PROTOCOL, record_protocol.data,
+                     record_protocol.size),
+              0);
+  } else {
+    ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_RECORD_PROTOCOL,
+                     record_protocol.data, record_protocol.size),
+              0);
+  }
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_PEER_IDENTITY, peer_account.data,
                    peer_account.size),
             0);
@@ -481,11 +529,18 @@ static void on_server_next_success_cb(tsi_result status, void* user_data,
                  ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_VALUE)));
   }
 
-  // Check security level.
-  ASSERT_EQ(
-      memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
-             peer.properties[4].value.data, peer.properties[4].value.length),
-      0);
+  // Validate security level.
+  if (is_integrity_only) {
+    ASSERT_EQ(
+        memcmp(tsi_security_level_to_string(TSI_INTEGRITY_ONLY),
+               peer.properties[4].value.data, peer.properties[4].value.length),
+        0);
+  } else {
+    ASSERT_EQ(
+        memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
+               peer.properties[4].value.data, peer.properties[4].value.length),
+        0);
+  }
 
   tsi_peer_destruct(&peer);
   // Validate unused bytes.
@@ -506,7 +561,25 @@ static void on_server_next_success_cb(tsi_result status, void* user_data,
   signal(&tsi_to_caller_notification);
 }
 
-static tsi_result mock_client_start(alts_handshaker_client* client) {
+void OnServerNextSuccessIntegrityOnlyCb(tsi_result status, void* user_data,
+                                        const unsigned char* bytes_to_send,
+                                        size_t bytes_to_send_size,
+                                        tsi_handshaker_result* result) {
+  return OnServerNextSuccessBase(status, user_data, bytes_to_send,
+                                 bytes_to_send_size, result,
+                                 /*is_integrity_only=*/true);
+}
+
+void OnServerNextSuccessCb(tsi_result status, void* user_data,
+                           const unsigned char* bytes_to_send,
+                           size_t bytes_to_send_size,
+                           tsi_handshaker_result* result) {
+  return OnServerNextSuccessBase(status, user_data, bytes_to_send,
+                                 bytes_to_send_size, result,
+                                 /*is_integrity_only=*/false);
+}
+
+tsi_result MockClientStart(alts_handshaker_client* client) {
   if (!should_handshaker_client_api_succeed) {
     return TSI_INTERNAL_ERROR;
   }
@@ -515,7 +588,7 @@ static tsi_result mock_client_start(alts_handshaker_client* client) {
   // before the call to alts_handshaker_client_start is made because
   // because it's unsafe to access it afterwards.
   alts_handshaker_client_check_fields_for_testing(
-      client, on_client_start_success_cb, nullptr, true, nullptr);
+      client, OnClientStartSuccessCb, nullptr, true, nullptr);
   // Populate handshaker response for client_start request.
   grpc_byte_buffer** recv_buffer_ptr =
       alts_handshaker_client_get_recv_buffer_addr_for_testing(client);
@@ -525,15 +598,15 @@ static tsi_result mock_client_start(alts_handshaker_client* client) {
   return TSI_OK;
 }
 
-static void mock_shutdown(alts_handshaker_client* /*self*/) {}
+void MockShutdown(alts_handshaker_client* /*self*/) {}
 
-static tsi_result mock_server_start(alts_handshaker_client* client,
-                                    grpc_slice* bytes_received) {
+tsi_result MockServerStart(alts_handshaker_client* client,
+                           grpc_slice* bytes_received) {
   if (!should_handshaker_client_api_succeed) {
     return TSI_INTERNAL_ERROR;
   }
   alts_handshaker_client_check_fields_for_testing(
-      client, on_server_start_success_cb, nullptr, true, nullptr);
+      client, OnServerStartSuccessCb, nullptr, true, nullptr);
   EXPECT_EQ(memcmp(GRPC_SLICE_START_PTR(*bytes_received),
                    ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
                    GRPC_SLICE_LENGTH(*bytes_received)),
@@ -547,16 +620,21 @@ static tsi_result mock_server_start(alts_handshaker_client* client,
   return TSI_OK;
 }
 
-static tsi_result mock_next(alts_handshaker_client* client,
-                            grpc_slice* bytes_received) {
+tsi_result MockNextBase(alts_handshaker_client* client,
+                        grpc_slice* bytes_received, bool is_integrity_only) {
   if (!should_handshaker_client_api_succeed) {
     return TSI_INTERNAL_ERROR;
   }
   alts_tsi_handshaker* handshaker =
       alts_handshaker_client_get_handshaker_for_testing(client);
   bool is_client = alts_tsi_handshaker_get_is_client_for_testing(handshaker);
-  tsi_handshaker_on_next_done_cb cb =
-      is_client ? on_client_next_success_cb : on_server_next_success_cb;
+  tsi_handshaker_on_next_done_cb cb;
+  if (is_integrity_only) {
+    cb = is_client ? OnClientNextSuccessIntegrityOnlyCb
+                   : OnServerNextSuccessIntegrityOnlyCb;
+  } else {
+    cb = is_client ? OnClientNextSuccessCb : OnServerNextSuccessCb;
+  }
   alts_handshaker_client_set_cb_for_testing(client, cb);
   alts_handshaker_client_set_recv_bytes_for_testing(client, bytes_received);
   alts_handshaker_client_check_fields_for_testing(client, cb, nullptr, true,
@@ -571,8 +649,12 @@ static tsi_result mock_next(alts_handshaker_client* client,
       grpc_slice_from_static_string(ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME);
   grpc_byte_buffer** recv_buffer_ptr =
       alts_handshaker_client_get_recv_buffer_addr_for_testing(client);
-  *recv_buffer_ptr = is_client ? generate_handshaker_response(CLIENT_NEXT)
-                               : generate_handshaker_response(SERVER_NEXT);
+  *recv_buffer_ptr =
+      is_client
+          ? generate_handshaker_response(
+                is_integrity_only ? CLIENT_NEXT_INTEGRITY_ONLY : CLIENT_NEXT)
+          : generate_handshaker_response(
+                is_integrity_only ? SERVER_NEXT_INTEGRITY_ONLY : SERVER_NEXT);
   alts_handshaker_client_set_recv_bytes_for_testing(client, &out_frame);
   cb_event = client;
   signal(&caller_to_tsi_notification);
@@ -580,13 +662,27 @@ static tsi_result mock_next(alts_handshaker_client* client,
   return TSI_OK;
 }
 
-static void mock_destruct(alts_handshaker_client* /*client*/) {}
+tsi_result MockNext(alts_handshaker_client* client,
+                    grpc_slice* bytes_received) {
+  return MockNextBase(client, bytes_received, /*is_integrity_only=*/false);
+}
 
-static alts_handshaker_client_vtable vtable = {mock_client_start,
-                                               mock_server_start, mock_next,
-                                               mock_shutdown, mock_destruct};
+tsi_result MockNextIntegrityOnly(alts_handshaker_client* client,
+                                 grpc_slice* bytes_received) {
+  return MockNextBase(client, bytes_received, /*is_integrity_only=*/true);
+}
 
-static tsi_handshaker* create_test_handshaker(bool is_client) {
+void MockDestruct(alts_handshaker_client* /*client*/) {}
+
+static alts_handshaker_client_vtable vtable = {
+    MockClientStart, MockServerStart, MockNext, MockShutdown, MockDestruct};
+
+static alts_handshaker_client_vtable integrity_only_vtable = {
+    MockClientStart, MockServerStart, MockNextIntegrityOnly, MockShutdown,
+    MockDestruct};
+
+tsi_handshaker* CreateTestHandshaker(bool is_client,
+                                     bool is_integrity_only = false) {
   tsi_handshaker* handshaker = nullptr;
   grpc_alts_credentials_options* options =
       grpc_alts_credentials_client_options_create();
@@ -596,7 +692,8 @@ static tsi_handshaker* create_test_handshaker(bool is_client) {
                              ALTS_TSI_HANDSHAKER_PREFERRED_TRANSPORT_PROTOCOL);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
-  alts_tsi_handshaker_set_client_vtable_for_testing(alts_handshaker, &vtable);
+  alts_tsi_handshaker_set_client_vtable_for_testing(
+      alts_handshaker, is_integrity_only ? &integrity_only_vtable : &vtable);
   grpc_alts_credentials_options_destroy(options);
   return handshaker;
 }
@@ -610,7 +707,7 @@ static void run_tsi_handshaker_destroy_with_exec_ctx(
 TEST(AltsTsiHandshakerTest, CheckHandshakerNextInvalidInput) {
   should_handshaker_client_api_succeed = true;
   // Initialization.
-  tsi_handshaker* handshaker = create_test_handshaker(true);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true);
   // Check nullptr handshaker.
   ASSERT_EQ(tsi_handshaker_next(nullptr, nullptr, 0, nullptr, nullptr, nullptr,
                                 check_must_not_be_called, nullptr),
@@ -626,7 +723,7 @@ TEST(AltsTsiHandshakerTest, CheckHandshakerNextInvalidInput) {
 TEST(AltsTsiHandshakerTest, CheckHandshakerShutdownInvalidInput) {
   should_handshaker_client_api_succeed = false;
   // Initialization.
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   // Check nullptr handshaker.
   tsi_handshaker_shutdown(nullptr);
   // Cleanup.
@@ -639,12 +736,12 @@ static void check_handshaker_next_success() {
   /// correctness check.
   ///
   tsi_handshaker* client_handshaker =
-      create_test_handshaker(true /* is_client */);
+      CreateTestHandshaker(true /* is_client */);
   tsi_handshaker* server_handshaker =
-      create_test_handshaker(false /* is_client */);
+      CreateTestHandshaker(false /* is_client */);
   // Client start.
   ASSERT_EQ(tsi_handshaker_next(client_handshaker, nullptr, 0, nullptr, nullptr,
-                                nullptr, on_client_start_success_cb, nullptr),
+                                nullptr, OnClientStartSuccessCb, nullptr),
             TSI_ASYNC);
   wait(&tsi_to_caller_notification);
   // Client next.
@@ -652,7 +749,7 @@ static void check_handshaker_next_success() {
                 client_handshaker,
                 (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
                 strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
-                nullptr, on_client_next_success_cb, nullptr),
+                nullptr, OnClientNextSuccessCb, nullptr),
             TSI_ASYNC);
   wait(&tsi_to_caller_notification);
   // Server start.
@@ -660,7 +757,7 @@ static void check_handshaker_next_success() {
                 server_handshaker,
                 (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
                 strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
-                nullptr, on_server_start_success_cb, nullptr),
+                nullptr, OnServerStartSuccessCb, nullptr),
             TSI_ASYNC);
   wait(&tsi_to_caller_notification);
   // Server next.
@@ -668,7 +765,50 @@ static void check_handshaker_next_success() {
                 server_handshaker,
                 (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
                 strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
-                nullptr, on_server_next_success_cb, nullptr),
+                nullptr, OnServerNextSuccessCb, nullptr),
+            TSI_ASYNC);
+  wait(&tsi_to_caller_notification);
+  // Cleanup.
+  run_tsi_handshaker_destroy_with_exec_ctx(server_handshaker);
+  run_tsi_handshaker_destroy_with_exec_ctx(client_handshaker);
+}
+
+void CheckHandshakerNextSuccessIntegrityOnly() {
+  ///
+  /// Create handshakers for which internal mock client is going to do
+  /// correctness check.
+  ///
+  tsi_handshaker* client_handshaker =
+      CreateTestHandshaker(/*is_client=*/true, /*is_integrity_only=*/true);
+  tsi_handshaker* server_handshaker = CreateTestHandshaker(
+      /*is_client=*/false, /*is_integrity_only=*/true);
+  // Client start.
+  ASSERT_EQ(tsi_handshaker_next(client_handshaker, nullptr, 0, nullptr, nullptr,
+                                nullptr, OnClientStartSuccessCb, nullptr),
+            TSI_ASYNC);
+  wait(&tsi_to_caller_notification);
+  // Client next.
+  ASSERT_EQ(tsi_handshaker_next(
+                client_handshaker,
+                (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
+                strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
+                nullptr, OnClientNextSuccessIntegrityOnlyCb, nullptr),
+            TSI_ASYNC);
+  wait(&tsi_to_caller_notification);
+  // Server start.
+  ASSERT_EQ(tsi_handshaker_next(
+                server_handshaker,
+                (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
+                strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
+                nullptr, OnServerStartSuccessCb, nullptr),
+            TSI_ASYNC);
+  wait(&tsi_to_caller_notification);
+  // Server next.
+  ASSERT_EQ(tsi_handshaker_next(
+                server_handshaker,
+                (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
+                strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
+                nullptr, OnServerNextSuccessIntegrityOnlyCb, nullptr),
             TSI_ASYNC);
   wait(&tsi_to_caller_notification);
   // Cleanup.
@@ -677,10 +817,10 @@ static void check_handshaker_next_success() {
 }
 
 static void check_handshaker_next_with_shutdown() {
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client*/);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client*/);
   // next(success) -- shutdown(success) -- next (fail)
   ASSERT_EQ(tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr,
-                                nullptr, on_client_start_success_cb, nullptr),
+                                nullptr, OnClientStartSuccessCb, nullptr),
             TSI_ASYNC);
   wait(&tsi_to_caller_notification);
   tsi_handshaker_shutdown(handshaker);
@@ -688,7 +828,7 @@ static void check_handshaker_next_with_shutdown() {
       tsi_handshaker_next(
           handshaker, (const unsigned char*)ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES,
           strlen(ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES), nullptr, nullptr,
-          nullptr, on_client_next_success_cb, nullptr),
+          nullptr, OnClientNextSuccessCb, nullptr),
       TSI_HANDSHAKE_SHUTDOWN);
   // Cleanup.
   run_tsi_handshaker_destroy_with_exec_ctx(handshaker);
@@ -705,9 +845,9 @@ TEST(AltsTsiHandshakerTest, CheckHandshakerNextFailure) {
   /// Create handshakers for which internal mock client is always going to fail.
   ///
   tsi_handshaker* client_handshaker =
-      create_test_handshaker(true /* is_client */);
+      CreateTestHandshaker(true /* is_client */);
   tsi_handshaker* server_handshaker =
-      create_test_handshaker(false /* is_client */);
+      CreateTestHandshaker(false /* is_client */);
   // Client start.
   ASSERT_EQ(tsi_handshaker_next(client_handshaker, nullptr, 0, nullptr, nullptr,
                                 nullptr, check_must_not_be_called, nullptr),
@@ -741,7 +881,7 @@ TEST(AltsTsiHandshakerTest, CheckHandshakerNextFailure) {
 TEST(AltsTsiHandshakerTest, CheckHandshakerNextIncomplete) {
   should_handshaker_client_api_succeed = false;
   tsi_handshaker* server_handshaker =
-      create_test_handshaker(false /* is_client */);
+      CreateTestHandshaker(false /* is_client */);
   // Server start.
   ASSERT_EQ(tsi_handshaker_next(server_handshaker, nullptr, 0, nullptr, nullptr,
                                 nullptr, check_must_not_be_called, nullptr),
@@ -781,9 +921,9 @@ TEST(AltsTsiHandshakerTest, CheckHandleResponseNullptrHandshaker) {
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   grpc_slice slice = grpc_empty_slice();
@@ -821,9 +961,9 @@ TEST(AltsTsiHandshakerTest, CheckHandleResponseNullptrRecvBytes) {
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   alts_handshaker_client* client =
@@ -855,9 +995,9 @@ TEST(AltsTsiHandshakerTest,
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   grpc_slice slice = grpc_empty_slice();
@@ -892,9 +1032,9 @@ TEST(AltsTsiHandshakerTest,
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   grpc_slice slice = grpc_empty_slice();
@@ -939,9 +1079,9 @@ TEST(AltsTsiHandshakerTest, CheckHandleResponseInvalidResp) {
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   alts_handshaker_client* client =
@@ -1011,9 +1151,9 @@ TEST(AltsTsiHandshakerTest, CheckHandleResponseFailure) {
   /// Create a handshaker at the client side, for which internal mock client is
   /// always going to fail.
   ///
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   alts_handshaker_client* client =
@@ -1052,9 +1192,9 @@ TEST(AltsTsiHandshakerTest, CheckHandleResponseAfterShutdown) {
   // Initialization.
   notification_init(&caller_to_tsi_notification);
   notification_init(&tsi_to_caller_notification);
-  tsi_handshaker* handshaker = create_test_handshaker(true /* is_client */);
+  tsi_handshaker* handshaker = CreateTestHandshaker(true /* is_client */);
   tsi_handshaker_next(handshaker, nullptr, 0, nullptr, nullptr, nullptr,
-                      on_client_start_success_cb, nullptr);
+                      OnClientStartSuccessCb, nullptr);
   alts_tsi_handshaker* alts_handshaker =
       reinterpret_cast<alts_tsi_handshaker*>(handshaker);
   alts_handshaker_client* client =
@@ -1115,6 +1255,22 @@ TEST(AltsTsiHandshakerTest, CheckHandshakerSuccess) {
   notification_destroy(&tsi_to_caller_notification);
 }
 
+TEST(AltsTsiHandshakerTest, CheckHandshakerIntegrityOnlySecurityLevel) {
+  should_handshaker_client_api_succeed = true;
+  // Initialization.
+  notification_init(&caller_to_tsi_notification);
+  notification_init(&tsi_to_caller_notification);
+  // Tests.
+  grpc_core::Thread thd("alts_tsi_handshaker_test",
+                        &check_handle_response_success, nullptr);
+  thd.Start();
+  CheckHandshakerNextSuccessIntegrityOnly();
+  thd.Join();
+  // Cleanup.
+  notification_destroy(&caller_to_tsi_notification);
+  notification_destroy(&tsi_to_caller_notification);
+}
+
 int main(int argc, char** argv) {
   grpc::testing::TestEnvironment env(&argc, argv);
   ::testing::InitGoogleTest(&argc, argv);
