@@ -14,10 +14,10 @@
 
 #include "src/core/util/cpp_impl_of.h"
 
-#include <gtest/gtest.h>
-
 #include <memory>
 
+#include "gtest/gtest.h"
+
 typedef struct grpc_foo grpc_foo;
 
 namespace grpc_core {
