@@ -27,25 +27,31 @@
 #include <thread>
 #include <vector>
 
-#include "absl/container/flat_hash_map.h"
-#include "absl/container/flat_hash_set.h"
-#include "absl/log/log.h"
 #include "envoy/config/cluster/v3/cluster.pb.h"
 #include "envoy/config/endpoint/v3/endpoint.pb.h"
 #include "envoy/config/listener/v3/listener.pb.h"
 #include "envoy/config/route/v3/route.pb.h"
+#include "envoy/service/discovery/v3/ads.grpc.pb.h"
+#include "envoy/service/discovery/v3/discovery.pb.h"
+#include "envoy/service/load_stats/v3/lrs.grpc.pb.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/util/crash.h"
 #include "src/core/util/grpc_check.h"
 #include "src/core/util/sync.h"
-#include "src/proto/grpc/testing/xds/v3/ads.grpc.pb.h"
-#include "src/proto/grpc/testing/xds/v3/discovery.pb.h"
-#include "src/proto/grpc/testing/xds/v3/lrs.grpc.pb.h"
 #include "test/core/test_util/test_config.h"
 #include "test/cpp/end2end/counted_service.h"
+#include "absl/container/flat_hash_map.h"
+#include "absl/container/flat_hash_set.h"
+#include "absl/log/log.h"
 
 namespace grpc {
 namespace testing {
+namespace internal {
+using AggregatedDiscoveryService =
+    envoy::service::discovery::v3::AggregatedDiscoveryService;
+using LoadReportingService =
+    envoy::service::load_stats::v3::LoadReportingService;
+}  // namespace internal
 
 constexpr char kLdsTypeUrl[] =
     "type.googleapis.com/envoy.config.listener.v3.Listener";
@@ -58,8 +64,8 @@ constexpr char kEdsTypeUrl[] =
 
 // An ADS service implementation.
 class AdsServiceImpl
-    : public CountedService<::envoy::service::discovery::v3::
-                                AggregatedDiscoveryService::CallbackService>,
+    : public CountedService<
+          internal::AggregatedDiscoveryService::CallbackService>,
       public std::enable_shared_from_this<AdsServiceImpl> {
  public:
   using DiscoveryRequest = ::envoy::service::discovery::v3::DiscoveryRequest;
@@ -309,8 +315,7 @@ class AdsServiceImpl
 
 // An LRS service implementation.
 class LrsServiceImpl
-    : public CountedService<::envoy::service::load_stats::v3::
-                                LoadReportingService::CallbackService>,
+    : public CountedService<internal::LoadReportingService::CallbackService>,
       public std::enable_shared_from_this<LrsServiceImpl> {
  public:
   using LoadStatsRequest = ::envoy::service::load_stats::v3::LoadStatsRequest;
