@@ -28,7 +28,7 @@ tools/bazel query --noimplicit_deps --output=xml 'kind(http_archive, //external:
 
 # PHASE 1: generate artifacts
 cd tools/artifact_gen
-../../tools/bazel build -c opt :artifact_gen 
+../../tools/bazel build -c opt --cxxopt='-std=c++17' :artifact_gen 
 bazel-bin/artifact_gen \
 	--target_query=`pwd`/test_deps.xml,`pwd`/root_all_deps.xml,`pwd`/compiler_deps.xml,`pwd`/third_party_alias_deps.xml,`pwd`/envoy_api_proto_deps.xml,`pwd`/upb_deps.xml \
 	--external_http_archive_query=`pwd`/external_http_archive_deps.xml \
