@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# This script is meant to be ran in Docker instance of python:3.8.
+# This script is meant to be ran in Docker instance of python:3.9.
 
 set -ex
 
@@ -23,9 +23,14 @@ set -ex
 HOME="$(mktemp -d)"
 export HOME
 
+SOURCE_DIR="doc/python/sphinx"
+TARGET_DIR="doc/build"
+
 pip install -r tools/distrib/docgen/requirements.docs.lock
 tools/run_tests/run_tests.py -c opt -l python --compiler python3.9 --newline_on_success -j 8 --build_only
 # shellcheck disable=SC1091
 source py39/bin/activate
 pip install --upgrade Sphinx
-python setup.py doc
+
+# Use direct sphinx-build CLI command instead of `python setup.py doc`
+sphinx-build -b html -W --keep-going "$SOURCE_DIR" "$TARGET_DIR"
