@@ -23,25 +23,11 @@ cd $(dirname $0)/../../..
 
 source tools/internal_ci/helper_scripts/prepare_build_linux_rc
 
-IS_AARCH64_MUSL=""
-if [[ "${TASK_RUNNER_EXTRA_FILTERS}" == "aarch64 musllinux_1_1" || "${TASK_RUNNER_EXTRA_FILTERS}" == "presubmit aarch64 musllinux_1_1" ]]; then
-  IS_AARCH64_MUSL="True"
-fi
-
-if [[ "${IS_AARCH64_MUSL}" == "True" ]]; then
-  echo "Skipping prepare_qemu_rc'"
-else
-  # some distribtests use a pre-registered binfmt_misc hook
-  # to automatically execute foreign binaries (such as aarch64)
-  # under qemu emulator.
-  source tools/internal_ci/helper_scripts/prepare_qemu_rc
-fi
-
 # configure ccache
 source tools/internal_ci/helper_scripts/prepare_ccache_rc
 
 # Build all python linux artifacts (this step actually builds all the binary wheels and source archives)
-tools/run_tests/task_runner.py -f artifact linux python ${TASK_RUNNER_EXTRA_FILTERS} -j 12 -x build_artifacts/sponge_log.xml || FAILED="true"
+tools/run_tests/task_runner.py -f artifact linux python ${TASK_RUNNER_EXTRA_FILTERS} -j 12 -x build_artifacts/sponge_log.xml || BUILD_ARTIFACT_FAILED="true"
 
 # the next step expects to find the artifacts from the previous step in the "input_artifacts" folder.
 rm -rf input_artifacts
@@ -52,7 +38,7 @@ cp -r artifacts/* input_artifacts/ || true
 
 # PythonPackage targets do not support the `presubmit` label.
 # For this reason we remove `presubmit` label selector from TASK_RUNNER_EXTRA_FILTERS,
-# which looks like TASK_RUNNER_EXTRA_FILTERS="presubmit -e aarch64 musllinux_1_1"
+# which looks like TASK_RUNNER_EXTRA_FILTERS="presubmit -e aarch64 musllinux_1_2"
 # for a presubmit with an exclude filter.
 PACKAGE_TASK_RUNNER_EXTRA_FILTERS="${TASK_RUNNER_EXTRA_FILTERS//presubmit /}"
 
@@ -65,14 +51,14 @@ rm -rf input_artifacts
 mkdir -p input_artifacts
 cp -r artifacts/* input_artifacts/ || true
 
+# exit early if build_artifact or package task fails, for faster test run time
+if [[ "$BUILD_ARTIFACT_FAILED" != "" || "$FAILED" != "" ]]; then
+  exit 1
+fi
+
 # Run all python linux distribtests
-# We run the distribtests even if some of the artifacts have failed to build, since that gives
-# a better signal about which distribtest are affected by the currently broken artifact builds.
 
-# We're using alpine as tag in distribtest targets for musllinux_1_1 artifacts, so exclude filters must use this tag 
-DISTRIB_TASK_RUNNER_EXTRA_FILTERS="${TASK_RUNNER_EXTRA_FILTERS//musllinux_1_1/alpine}"
-
-tools/run_tests/task_runner.py -f distribtest linux python ${DISTRIB_TASK_RUNNER_EXTRA_FILTERS} -j 12 -x distribtests/sponge_log.xml || FAILED="true"
+tools/run_tests/task_runner.py -f distribtest linux python ${TASK_RUNNER_EXTRA_FILTERS} -j 12 -x distribtests/sponge_log.xml || FAILED="true"
 
 # This step checks if any of the artifacts exceeds a per-file size limit.
 tools/internal_ci/helper_scripts/check_python_artifacts_size.sh
