@@ -143,6 +143,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.72.0", ReleaseInfo()),
             ("v1.73.0", ReleaseInfo()),
             ("v1.74.0", ReleaseInfo()),
+            ("v1.75.1", ReleaseInfo()),
+            ("v1.76.0", ReleaseInfo()),
         ]
     ),
     "go": OrderedDict(
@@ -318,9 +320,11 @@ LANG_RELEASE_MATRIX = {
             ("v1.69.4", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
             ("v1.71.3", ReleaseInfo()),
-            ("v1.72.2", ReleaseInfo()),
-            ("v1.73.0", ReleaseInfo()),
-            ("v1.74.2", ReleaseInfo()),
+            ("v1.72.3", ReleaseInfo()),
+            ("v1.73.1", ReleaseInfo()),
+            ("v1.74.3", ReleaseInfo()),
+            ("v1.75.1", ReleaseInfo()),
+            ("v1.76.0", ReleaseInfo()),
         ]
     ),
     "java": OrderedDict(
@@ -473,6 +477,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.71.0", ReleaseInfo()),
             ("v1.72.0", ReleaseInfo()),
             ("v1.73.0", ReleaseInfo()),
+            ("v1.74.0", ReleaseInfo()),
+            ("v1.75.0", ReleaseInfo()),
+            ("v1.76.0", ReleaseInfo()),
         ]
     ),
     "python": OrderedDict(
@@ -879,6 +886,21 @@ LANG_RELEASE_MATRIX = {
                     runtimes=["python"], testcases_file="python__master"
                 ),
             ),
+            (
+                "v1.75.1",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
+            # Python images can't be anymore built without #40959 temporary fix,
+            # or #40833 proper pyproject migration.
+            # TODO(sreenithi): update this once v1.76.1 is out.
+            # (
+            #     "v1.76.0",
+            #     ReleaseInfo(
+            #         runtimes=["python"], testcases_file="python__master"
+            #     ),
+            # ),
         ]
     ),
     "node": OrderedDict(
@@ -986,6 +1008,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.72.0", ReleaseInfo()),
             ("v1.73.0", ReleaseInfo()),
             ("v1.74.0", ReleaseInfo()),
+            ("v1.75.1", ReleaseInfo()),
+            ("v1.76.0", ReleaseInfo()),
         ]
     ),
     "php": OrderedDict(
@@ -1056,6 +1080,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.72.0", ReleaseInfo()),
             ("v1.73.0", ReleaseInfo()),
             ("v1.74.0", ReleaseInfo()),
+            ("v1.75.1", ReleaseInfo()),
+            ("v1.76.0", ReleaseInfo()),
         ]
     ),
     "csharp": OrderedDict(
