@@ -120,7 +120,7 @@ class CSharpDistribTest(object):
         return []
 
     def build_jobspec(self, inner_jobs=None):
-        del inner_jobs  # arg unused as there is little opportunity for parallelizing whats inside the distribtests
+        del inner_jobs  # arg unused as there is little opportunity for parallelizing what's inside the distribtests
         if self.platform == "linux":
             return create_docker_jobspec(
                 self.name,
